@@ -45,19 +45,24 @@ char *findCommand(char *command);
 /* Global Variables */
 char*  defaultVM     = "java";
 char*  vmLibrary	 = "JavaVM";
-char*  shippedVMDir  = "jre/bin/";
+char*  shippedVMDir  = "../../../jre/Contents/Home/jre/bin/";
+int isSUN = 0;
 
 static void adjustLibraryPath(char * vmLibrary);
 static char * findLib(char * command);
 
 #ifdef i386
 #define JAVA_ARCH "i386"
+#define JAVA_HOME_ARCH "i386"
 #elif defined(__ppc__) || defined(__powerpc64__)
 #define JAVA_ARCH "ppc"
+#define JAVA_HOME_ARCH "ppc"
 #elif defined(__amd64__) || defined(__x86_64__)
 #define JAVA_ARCH "amd64"
+#define JAVA_HOME_ARCH "x86_64"
 #else
 #define JAVA_ARCH DEFAULT_OS_ARCH
+#define JAVA_HOME_ARCH DEFAULT_OS_ARCH
 #endif
 
 #define LIB_PATH_VAR _T_ECLIPSE("LD_LIBRARY_PATH")
@@ -469,10 +474,68 @@ char** getArgVM( char* vm )
 	return result;
 }
 
+char * getJavaVersion(char* command) {
+	FILE *fp;
+	char buffer[4096];
+	char *version = NULL, *firstChar;
+    int numChars = 0;
+	sprintf(buffer,"%s -version 2>&1", command);
+	fp = popen(buffer, "r");
+	if (fp == NULL) {
+		return NULL;
+	}
+	while (fgets(buffer, sizeof(buffer)-1, fp) != NULL) {
+		if (!version) {
+			firstChar = (char *) (strchr(buffer, '"') + 1);
+			if (firstChar != NULL)
+				numChars = (int)  (strrchr(buffer, '"') - firstChar);
+
+			/* Allocate a buffer and copy the version string into it. */
+			if (numChars > 0)
+			{
+				version = malloc( numChars + 1 );
+				strncpy(version, firstChar, numChars);
+				version[numChars] = '\0';
+			}
+		}
+		if (strstr(buffer, "Java HotSpot(TM)") || strstr(buffer, "OpenJDK")) {
+			isSUN = 1;
+			break;
+		}
+		if (strstr(buffer, "IBM") != NULL) {
+			isSUN = 0;
+			break;
+		}
+	}
+	pclose(fp);
+	return version;
+}
+
+char * getJavaHome() {
+	FILE *fp;
+	char path[4096];
+	char *result, *start;
+	sprintf(path, "/usr/libexec/java_home -a %s", JAVA_HOME_ARCH);
+	fp = popen(path, "r");
+	if (fp == NULL) {
+		return NULL;
+	}
+	while (fgets(path, sizeof(path)-1, fp) != NULL) {
+	}
+	result = path;
+	start = strchr(result, '\n');
+	if (start) {
+		start[0] = 0;
+	}
+	sprintf(path, "%s/bin/java", result);
+	pclose(fp);
+	return strdup(path);
+}
+
 char * findVMLibrary( char* command ) {
 	char *start, *end;
 	char *version;
-	int length;
+	int length, isJDK7;
 	
 	/*check first to see if command already points to the library */
 	if (strcmp(command, JAVA_FRAMEWORK) == 0) {
@@ -497,7 +560,23 @@ char * findVMLibrary( char* command ) {
 			
 			free(version);
 		} 
-	} else if (strstr(command, "/JavaVM.framework/") == NULL) {
+	}
+	char *java_home = NULL, *cmd = command;
+	if (strstr(cmd, "/JavaVM.framework/") != NULL && (strstr(cmd, "/Current/") != NULL || strstr(cmd, "/A/") != NULL)) {
+		java_home = cmd = getJavaHome();
+	}
+	version = getJavaVersion(cmd);
+	isJDK7 = version && versionCmp(version, "1.7.0") >= 0;
+	if (version) free(version);
+	if (isJDK7) {
+		start = strstr(cmd, "/Contents/");
+		if (start != NULL){
+			start[0] = 0;
+			return cmd;
+		}
+	}
+	if (java_home) free(java_home);
+	if (strstr(command, "/JavaVM.framework/") == NULL) {
 		char * lib = findLib(command);
 		if (lib != NULL) {
 			adjustLibraryPath(lib);
@@ -815,6 +894,5 @@ void processVMArgs(char **vmargs[] )
 }
 
 int isSunVM( _TCHAR * javaVM, _TCHAR * jniLib ) {
-	_TCHAR *vm = (jniLib != NULL) ? jniLib : javaVM;
-	return (strncmp(vm, JAVA_FRAMEWORK, strlen(JAVA_FRAMEWORK)) == 0);
+	return isSUN;
 }
