@@ -48,10 +48,18 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 	/* (non-Javadoc)
 	 * @see IResource#accept(IResourceProxyVisitor, int)
 	 */
-	public void accept(final IResourceProxyVisitor visitor, final int memberFlags) throws CoreException {
+	public void accept(IResourceProxyVisitor visitor, int memberFlags) throws CoreException {
+		accept(visitor, IResource.DEPTH_INFINITE, memberFlags);
+	}
+
+	/* (non-Javadoc)
+	 * @see IResource#accept(IResourceProxyVisitor, int, int)
+	 */
+	public void accept(final IResourceProxyVisitor visitor, final int depth, final int memberFlags) throws CoreException {
 		// it is invalid to call accept on a phantom when INCLUDE_PHANTOMS is not specified
 		final boolean includePhantoms = (memberFlags & IContainer.INCLUDE_PHANTOMS) != 0;
-		checkAccessible(getFlags(getResourceInfo(includePhantoms, false)));
+		if ((memberFlags & IContainer.DO_NOT_CHECK_EXISTENCE) == 0)
+			checkAccessible(getFlags(getResourceInfo(includePhantoms, false)));
 
 		final ResourceProxy proxy = new ResourceProxy();
 		IElementContentVisitor elementVisitor = new IElementContentVisitor() {
@@ -62,7 +70,19 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 				proxy.requestor = requestor;
 				proxy.info = info;
 				try {
-					return visitor.visit(proxy);
+					boolean shouldContinue = true;
+					switch (depth) {
+						case DEPTH_ZERO :
+							shouldContinue = false;
+							break;
+						case DEPTH_ONE :
+							shouldContinue = !path.equals(requestor.requestPath().removeLastSegments(1));
+							break;
+						case DEPTH_INFINITE :
+							shouldContinue = true;
+							break;
+					}
+					return visitor.visit(proxy) && shouldContinue;
 				} catch (CoreException e) {
 					//throw an exception to bail out of the traversal
 					throw new WrappedRuntimeException(e);
@@ -112,7 +132,8 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		final boolean includePhantoms = (memberFlags & IContainer.INCLUDE_PHANTOMS) != 0;
 		ResourceInfo info = getResourceInfo(includePhantoms, false);
 		int flags = getFlags(info);
-		checkAccessible(flags);
+		if ((memberFlags & IContainer.DO_NOT_CHECK_EXISTENCE) == 0)
+			checkAccessible(flags);
 
 		//check that this resource matches the member flags
 		if (!isMember(flags, memberFlags))
@@ -132,7 +153,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		IContainer resource = getType() != type ? (IContainer) workspace.newResource(getFullPath(), type) : (IContainer) this;
 		IResource[] members = resource.members(memberFlags);
 		for (int i = 0; i < members.length; i++)
-			members[i].accept(visitor, DEPTH_ZERO, memberFlags);
+			members[i].accept(visitor, DEPTH_ZERO, memberFlags | IContainer.DO_NOT_CHECK_EXISTENCE);
 	}
 
 	protected void assertCopyRequirements(IPath destination, int destinationType, int updateFlags) throws CoreException {
@@ -201,7 +222,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		checkLocal(flags, depth);
 		return info;
 	}
-	
+
 	/**
 	 * This method reports errors in two different ways. It can throw a
 	 * CoreException or return a status. CoreExceptions are used according to the
@@ -496,7 +517,10 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		}
 		if (!(rule instanceof IResource))
 			return false;
-		return path.isPrefixOf(((IResource) rule).getFullPath());
+		IResource resource = (IResource) rule;
+		if (!workspace.equals(resource.getWorkspace()))
+			return false;
+		return path.isPrefixOf(resource.getFullPath());
 	}
 
 	public void convertToPhantom() throws CoreException {
@@ -674,7 +698,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 						// a problem happened updating the description, so delete the resource from the workspace
 						workspace.deleteResource(this);
 						throw e; // rethrow
-					}	
+					}
 				monitor.worked(Policy.opWork * 5 / 100);
 
 				//refresh to discover any new resources below this linked location
@@ -699,7 +723,6 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		}
 	}
 
-
 	/* (non-Javadoc)
 	 * @see IResource#createMarker(String)
 	 */
@@ -763,7 +786,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 					return;
 				workspace.beginOperation(true);
 				broadcastPreDeleteEvent();
-				
+
 				// when a project is being deleted, flush the build order in case there is a problem
 				if (this.getType() == IResource.PROJECT)
 					workspace.flushBuildOrder();
@@ -795,9 +818,12 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 				//note that deletion of a linked resource cannot affect other resources
 				if (!wasLinked)
 					workspace.getAliasManager().updateAliases(this, originalStore, IResource.DEPTH_INFINITE, monitor);
-				//make sure the rule factory is cleared on project deletion
-				if (getType() == PROJECT)
+				if (getType() == PROJECT) {
+					// make sure the rule factory is cleared on project deletion
 					((Rules) workspace.getRuleFactory()).setRuleFactory((IProject) this, null);
+					// make sure project deletion is remembered
+					workspace.getSaveManager().requestSnapshot();
+				}
 			} catch (OperationCanceledException e) {
 				workspace.getWorkManager().operationCanceled();
 				throw e;
@@ -865,7 +891,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 				}
 			}
 		}
-		
+
 		/* if we are synchronizing, do not delete the resource. Convert it
 		 into a phantom. Actual deletion will happen when we refresh or push. */
 		if (convertToPhantom && getType() != PROJECT && synchronizing(getResourceInfo(true, false)))
@@ -885,7 +911,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 				project.writeDescription(IResource.FORCE);
 			}
 		}
-		
+
 		// Delete properties after the resource is deleted from the tree. See bug 84584.
 		CoreException err = null;
 		try {
@@ -907,7 +933,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 	private List<Resource> findLinks() {
 		Project project = (Project) getProject();
 		ProjectDescription description = project.internalGetDescription();
-		HashMap<IPath,LinkDescription> linkMap = description.getLinks();
+		HashMap<IPath, LinkDescription> linkMap = description.getLinks();
 		if (linkMap == null)
 			return null;
 		List<Resource> links = null;
@@ -1036,7 +1062,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 	 */
 	private String findVariant(String target, String[] list) {
 		for (int i = 0; i < list.length; i++) {
-			if (target.equalsIgnoreCase(list[i]))
+			if (target.toUpperCase().equals(list[i].toUpperCase()))
 				return list[i];
 		}
 		return null;
@@ -1164,8 +1190,8 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 	public IContainer getParent() {
 		int segments = path.segmentCount();
 		//zero and one segments handled by subclasses
-		if (segments < 2) 
-            Assert.isLegal(false, path.toString());
+		if (segments < 2)
+			Assert.isLegal(false, path.toString());
 		if (segments == 2)
 			return workspace.getRoot().getProject(path.segment(0));
 		return (IFolder) workspace.newResource(path.removeLastSegments(1), IResource.FOLDER);
@@ -1252,7 +1278,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 	/* (non-Javadoc)
 	 * @see IResource#getSessionProperties()
 	 */
-	public Map<QualifiedName,Object> getSessionProperties() throws CoreException {
+	public Map<QualifiedName, Object> getSessionProperties() throws CoreException {
 		ResourceInfo info = checkAccessibleAndLocal(DEPTH_ZERO);
 		return info.getSessionProperties();
 	}
@@ -1329,12 +1355,19 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 	 * @see ISchedulingRule#isConflicting(ISchedulingRule)
 	 */
 	public boolean isConflicting(ISchedulingRule rule) {
+		if (this == rule)
+			return true;
 		//must not schedule at same time as notification
 		if (rule.getClass().equals(WorkManager.NotifyRule.class))
 			return true;
+		if (rule instanceof MultiRule)
+			return rule.isConflicting(this);
 		if (!(rule instanceof IResource))
 			return false;
-		IPath otherPath = ((IResource) rule).getFullPath();
+		IResource resource = (IResource) rule;
+		if (!workspace.equals(resource.getWorkspace()))
+			return false;
+		IPath otherPath = resource.getFullPath();
 		return path.isPrefixOf(otherPath) || otherPath.isPrefixOf(path);
 	}
 
@@ -1367,7 +1400,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		int flags = getFlags(info);
 		return flags != NULL_FLAG && ResourceInfo.isSet(flags, ICoreConstants.M_HIDDEN);
 	}
-	
+
 	/* (non-Javadoc)
 	 * @see IResource#isHidden(int)
 	 */
@@ -1400,7 +1433,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 			ProjectDescription desc = ((Project) project).internalGetDescription();
 			if (desc == null)
 				return false;
-			HashMap<IPath,LinkDescription> links = desc.getLinks();
+			HashMap<IPath, LinkDescription> links = desc.getLinks();
 			if (links == null)
 				return false;
 			IPath myPath = getProjectRelativePath();
@@ -1422,7 +1455,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		ResourceInfo info = getResourceInfo(false, false);
 		return info != null && info.isSet(M_VIRTUAL);
 	}
-	
+
 	/*
 	 * @return whether the current resource has a parent that is virtual.
 	 */
@@ -1512,7 +1545,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		int flags = getFlags(info);
 		return flags != NULL_FLAG && ResourceInfo.isSet(flags, ICoreConstants.M_TEAM_PRIVATE_MEMBER);
 	}
-	
+
 	/* (non-Javadoc)
 	 * @see IResource#isTeamPrivateMember(int)
 	 */
@@ -1607,6 +1640,9 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 				}
 				if (!tree.getStatus().isOK())
 					throw new ResourceException(tree.getStatus());
+				// if this is a project, make sure the move operation is remembered
+				if (getType() == PROJECT)
+					workspace.getSaveManager().requestSnapshot();
 			} catch (OperationCanceledException e) {
 				workspace.getWorkManager().operationCanceled();
 				throw e;
@@ -1744,7 +1780,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 				checkAccessible(getFlags(info));
 				// ignore attempts to set derived flag on anything except files and folders
 				if (info.getType() != FILE && info.getType() != FOLDER)
-					return;				
+					return;
 				workspace.beginOperation(true);
 				info = getResourceInfo(false, true);
 				if (isDerived)
@@ -1987,7 +2023,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		}
 		return true;
 	}
-	
+
 	private void broadcastPreDeleteEvent() throws CoreException {
 		switch (getType()) {
 			case IResource.PROJECT :
@@ -2000,7 +2036,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 					workspace.broadcastEvent(LifecycleEvent.newEvent(LifecycleEvent.PRE_PROJECT_DELETE, projects[i]));
 		}
 	}
-	
+
 	private void broadcastPreMoveEvent(final IResource destination, int updateFlags) throws CoreException {
 		switch (getType()) {
 			case IResource.FILE :
@@ -2049,11 +2085,11 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		}
 		return false;
 	}
-	
+
 	public boolean isFilteredWithException(boolean throwExeception) throws CoreException {
 		if (isLinked() || isVirtual())
 			return false;
-		
+
 		Project project = (Project) getProject();
 		if (project == null)
 			return false;
@@ -2080,7 +2116,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 		}
 		return false;
 	}
-	
+
 	public IFileInfo[] filterChildren(IFileInfo[] list, boolean throwException) throws CoreException {
 		Project project = (Project) getProject();
 		if (project == null)
@@ -2090,13 +2126,13 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 			return list;
 		return filterChildren(project, description, list, throwException);
 	}
-	
+
 	private IFileInfo[] filterChildren(Project project, ProjectDescription description, IFileInfo[] list, boolean throwException) throws CoreException {
 		IPath relativePath = getProjectRelativePath();
 		LinkedList<Filter> currentIncludeFilters = new LinkedList<Filter>();
 		LinkedList<Filter> currentExcludeFilters = new LinkedList<Filter>();
 		LinkedList<FilterDescription> filters = null;
-		
+
 		boolean firstSegment = true;
 		do {
 			if (!firstSegment)
@@ -2123,7 +2159,7 @@ public abstract class Resource extends PlatformObject implements IResource, ICor
 			}
 			firstSegment = false;
 		} while (relativePath.segmentCount() > 0);
-		
+
 		if ((currentIncludeFilters.size() > 0) || (currentExcludeFilters.size() > 0)) {
 			try {
 				list = Filter.filter(project, currentIncludeFilters, currentExcludeFilters, (IContainer) this, list);
