@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -26,17 +26,9 @@ import javax.xml.parsers.FactoryConfigurationError;
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.TransformerException;
 
-import com.ibm.icu.text.MessageFormat;
-
-import org.osgi.framework.BundleContext;
-import org.xml.sax.SAXException;
-import org.xml.sax.helpers.DefaultHandler;
-
-import org.w3c.dom.Document;
-import org.w3c.dom.Element;
-
-import org.eclipse.osgi.service.environment.Constants;
-
+import org.eclipse.core.resources.ISaveContext;
+import org.eclipse.core.resources.ISaveParticipant;
+import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IAdapterManager;
@@ -52,11 +44,6 @@ import org.eclipse.core.runtime.Plugin;
 import org.eclipse.core.runtime.SafeRunner;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.Job;
-
-import org.eclipse.core.resources.ISaveContext;
-import org.eclipse.core.resources.ISaveParticipant;
-import org.eclipse.core.resources.ResourcesPlugin;
-
 import org.eclipse.debug.core.model.IDebugElement;
 import org.eclipse.debug.core.model.IDisconnect;
 import org.eclipse.debug.core.model.IDropToFrame;
@@ -80,6 +67,14 @@ import org.eclipse.debug.internal.core.Preferences;
 import org.eclipse.debug.internal.core.StepFilterManager;
 import org.eclipse.debug.internal.core.commands.CommandAdapterFactory;
 import org.eclipse.debug.internal.core.sourcelookup.SourceLookupUtils;
+import org.eclipse.osgi.service.environment.Constants;
+import org.osgi.framework.BundleContext;
+import org.w3c.dom.Document;
+import org.w3c.dom.Element;
+import org.xml.sax.SAXException;
+import org.xml.sax.helpers.DefaultHandler;
+
+import com.ibm.icu.text.MessageFormat;
 
 /**
  * There is one instance of the debug plug-in available from
@@ -94,7 +89,7 @@ import org.eclipse.debug.internal.core.sourcelookup.SourceLookupUtils;
  * <li>status handlers</li>
  * </ul>
  * @noinstantiate This class is not intended to be instantiated by clients.
- * @noextend This class is not intended to be subclassed by clients.
+ * @noextend This class is not intended to be sub-classed by clients.
  */
 public class DebugPlugin extends Plugin {
 	
@@ -301,8 +296,6 @@ public class DebugPlugin extends Plugin {
 	 */
 	public static final String ATTR_BREAKPOINT_IS_DELETED= DebugPlugin.getUniqueIdentifier() + ".breakpointIsDeleted"; //$NON-NLS-1$
 
-
-	
 	/**
 	 * The singleton debug plug-in instance.
 	 */
@@ -364,7 +357,6 @@ public class DebugPlugin extends Plugin {
 	private static final int NOTIFY_FILTERS = 0;
 	private static final int NOTIFY_EVENTS = 1;
 
-		
 	/**
 	 * Queue of debug events to fire to listeners and asynchronous runnables to execute
 	 * in the order received.
@@ -653,7 +645,7 @@ public class DebugPlugin extends Plugin {
 	 */
 	public void start(BundleContext context) throws Exception {
 		super.start(context);
-		DebugOptions.initDebugOptions();
+		new DebugOptions(context);
 		ResourcesPlugin.getWorkspace().addSaveParticipant(getUniqueIdentifier(),
 				new ISaveParticipant() {
 					public void saving(ISaveContext saveContext) throws CoreException {
@@ -678,8 +670,6 @@ public class DebugPlugin extends Plugin {
 		manager.registerAdapters(actionFactory, ILaunch.class);
 		manager.registerAdapters(actionFactory, IProcess.class);
 		manager.registerAdapters(actionFactory, IDebugElement.class);	
-		getBreakpointManager();
-		fBreakpointManager.start();
 	}
 
 	/**
@@ -1145,7 +1135,7 @@ public class DebugPlugin extends Plugin {
 			Object[] listeners= getEventListeners();
 			if (DebugOptions.DEBUG_EVENTS) {
 				for (int i = 0; i < fEvents.length; i++) {
-					System.out.println(fEvents[i]);
+					DebugOptions.trace(fEvents[i].toString());
 				}
 			}
 			for (int i= 0; i < listeners.length; i++) {
@@ -1236,7 +1226,7 @@ public class DebugPlugin extends Plugin {
 	 * 
 	 * @param message error message
 	 * @param exception underlying exception, or <code>null</code>
-	 * @throws CoreException
+	 * @throws CoreException if a problem is encountered
 	 */
 	private static void abort(String message, Throwable exception) throws CoreException {
 		IStatus status = new Status(IStatus.ERROR, DebugPlugin.getUniqueIdentifier(), DebugPlugin.ERROR, message, exception);
