@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -16,6 +16,7 @@ package org.eclipse.debug.internal.ui;
 import java.lang.reflect.InvocationTargetException;
 import java.net.URL;
 import java.util.HashSet;
+import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.Set;
 
@@ -23,23 +24,12 @@ import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
-import com.ibm.icu.text.MessageFormat;
-
-import org.osgi.framework.Bundle;
-import org.osgi.framework.BundleContext;
-import org.osgi.service.packageadmin.PackageAdmin;
-import org.osgi.util.tracker.ServiceTracker;
-
-import org.w3c.dom.Document;
-
-import org.eclipse.swt.custom.BusyIndicator;
-import org.eclipse.swt.graphics.Color;
-import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.Shell;
-
 import org.eclipse.core.expressions.EvaluationContext;
 import org.eclipse.core.expressions.IEvaluationContext;
-
+import org.eclipse.core.resources.ISaveContext;
+import org.eclipse.core.resources.ISaveParticipant;
+import org.eclipse.core.resources.IncrementalProjectBuilder;
+import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.IConfigurationElement;
@@ -53,36 +43,8 @@ import org.eclipse.core.runtime.jobs.IJobChangeEvent;
 import org.eclipse.core.runtime.jobs.IJobChangeListener;
 import org.eclipse.core.runtime.jobs.IJobManager;
 import org.eclipse.core.runtime.jobs.Job;
-
-import org.eclipse.core.resources.ISaveContext;
-import org.eclipse.core.resources.ISaveParticipant;
-import org.eclipse.core.resources.IncrementalProjectBuilder;
-import org.eclipse.core.resources.ResourcesPlugin;
-
-import org.eclipse.jface.dialogs.ErrorDialog;
-import org.eclipse.jface.dialogs.IDialogConstants;
-import org.eclipse.jface.dialogs.MessageDialogWithToggle;
-import org.eclipse.jface.operation.IRunnableWithProgress;
-import org.eclipse.jface.preference.IPreferenceStore;
-import org.eclipse.jface.preference.PreferenceConverter;
-import org.eclipse.jface.resource.ImageDescriptor;
-import org.eclipse.jface.resource.ImageRegistry;
-import org.eclipse.jface.util.IPropertyChangeListener;
-import org.eclipse.jface.util.PropertyChangeEvent;
-import org.eclipse.jface.viewers.ILabelProvider;
-import org.eclipse.jface.viewers.IStructuredSelection;
-import org.eclipse.jface.viewers.StructuredSelection;
-import org.eclipse.jface.window.Window;
-
-import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.PlatformUI;
-import org.eclipse.ui.plugin.AbstractUIPlugin;
-import org.eclipse.ui.progress.IProgressConstants2;
-import org.eclipse.ui.progress.IProgressService;
-import org.eclipse.ui.services.IEvaluationService;
-import org.eclipse.ui.themes.IThemeManager;
-
+import org.eclipse.core.runtime.preferences.IEclipsePreferences;
+import org.eclipse.core.runtime.preferences.InstanceScope;
 import org.eclipse.debug.core.DebugException;
 import org.eclipse.debug.core.DebugPlugin;
 import org.eclipse.debug.core.ILaunch;
@@ -108,29 +70,96 @@ import org.eclipse.debug.internal.ui.launchConfigurations.PerspectiveManager;
 import org.eclipse.debug.internal.ui.sourcelookup.SourceLookupFacility;
 import org.eclipse.debug.internal.ui.sourcelookup.SourceLookupManager;
 import org.eclipse.debug.internal.ui.stringsubstitution.SelectedResourceManager;
+import org.eclipse.debug.internal.ui.viewers.model.provisional.IPresentationContext;
 import org.eclipse.debug.internal.ui.views.breakpoints.BreakpointOrganizerManager;
 import org.eclipse.debug.internal.ui.views.console.ProcessConsoleManager;
 import org.eclipse.debug.internal.ui.views.launch.DebugElementHelper;
-
 import org.eclipse.debug.ui.DebugUITools;
 import org.eclipse.debug.ui.IDebugModelPresentation;
 import org.eclipse.debug.ui.IDebugUIConstants;
 import org.eclipse.debug.ui.ILaunchGroup;
+import org.eclipse.jface.bindings.keys.KeyStroke;
+import org.eclipse.jface.dialogs.ErrorDialog;
+import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.dialogs.MessageDialogWithToggle;
+import org.eclipse.jface.operation.IRunnableWithProgress;
+import org.eclipse.jface.preference.IPreferenceStore;
+import org.eclipse.jface.preference.PreferenceConverter;
+import org.eclipse.jface.resource.ImageDescriptor;
+import org.eclipse.jface.resource.ImageRegistry;
+import org.eclipse.jface.util.IPropertyChangeListener;
+import org.eclipse.jface.util.PropertyChangeEvent;
+import org.eclipse.jface.viewers.ILabelProvider;
+import org.eclipse.jface.viewers.IStructuredSelection;
+import org.eclipse.jface.viewers.StructuredSelection;
+import org.eclipse.jface.window.Window;
+import org.eclipse.osgi.service.debug.DebugOptions;
+import org.eclipse.osgi.service.debug.DebugOptionsListener;
+import org.eclipse.osgi.service.debug.DebugTrace;
+import org.eclipse.swt.custom.BusyIndicator;
+import org.eclipse.swt.graphics.Color;
+import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.plugin.AbstractUIPlugin;
+import org.eclipse.ui.progress.IProgressConstants2;
+import org.eclipse.ui.progress.IProgressService;
+import org.eclipse.ui.services.IEvaluationService;
+import org.eclipse.ui.themes.IThemeManager;
+import org.osgi.framework.Bundle;
+import org.osgi.framework.BundleContext;
+import org.osgi.service.packageadmin.PackageAdmin;
+import org.osgi.service.prefs.BackingStoreException;
+import org.osgi.util.tracker.ServiceTracker;
+import org.w3c.dom.Document;
+
+import com.ibm.icu.text.MessageFormat;
 
 /**
  * The Debug UI Plug-in.
  * 
- * Since 3.3 this plugin registers an <code>ISaveParticipant</code>, allowing this plugin to participate
+ * Since 3.3 this plug-in registers an <code>ISaveParticipant</code>, allowing this plug-in to participate
  * in workspace persistence life-cycles
  * 
  * @see ISaveParticipant
  * @see ILaunchListener
  * @see LaunchConfigurationManager
  * @see PerspectiveManager
- * @see ContextLaunch
  */
-public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
+public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener, DebugOptionsListener {
 	
+	public static boolean DEBUG = false;
+	public static boolean DEBUG_BREAKPOINT_DELTAS = false;
+	public static boolean DEBUG_MODEL = false;
+	public static boolean DEBUG_VIEWER = false;
+	public static boolean DEBUG_BREADCRUMB = false;
+	public static boolean DEBUG_TREE_VIEWER_DROPDOWN = false;
+	public static boolean DEBUG_CONTENT_PROVIDER = false;
+	public static boolean DEBUG_UPDATE_SEQUENCE = false;
+	public static boolean DEBUG_DELTAS = false;
+	public static boolean DEBUG_STATE_SAVE_RESTORE = false;
+	public static String DEBUG_PRESENTATION_ID = null;
+	public static boolean DEBUG_DYNAMIC_LOADING = false;
+	
+	static final String DEBUG_FLAG = "org.eclipse.debug.ui/debug"; //$NON-NLS-1$
+	static final String DEBUG_BREAKPOINT_DELTAS_FLAG = "org.eclipse.debug.ui/debug/viewers/breakpointDeltas"; //$NON-NLS-1$
+	static final String DEBUG_MODEL_FLAG = "org.eclipse.debug.ui/debug/viewers/model"; //$NON-NLS-1$
+	static final String DEBUG_VIEWER_FLAG = "org.eclipse.debug.ui/debug/viewers/viewer"; //$NON-NLS-1$
+	static final String DEBUG_BREADCRUMB_FLAG = "org.eclipse.debug.ui/debug/breadcrumb"; //$NON-NLS-1$
+	static final String DEBUG_TREE_VIEWER_DROPDOWN_FLAG = "org.eclipse.debug.ui/debug/breadcrumb"; //$NON-NLS-1$
+	static final String DEBUG_CONTENT_PROVIDER_FLAG ="org.eclipse.debug.ui/debug/viewers/contentProvider"; //$NON-NLS-1$
+	static final String DEBUG_UPDATE_SEQUENCE_FLAG = "org.eclipse.debug.ui/debug/viewers/updateSequence"; //$NON-NLS-1$
+	static final String DEBUG_DELTAS_FLAG ="org.eclipse.debug.ui/debug/viewers/deltas"; //$NON-NLS-1$
+	static final String DEBUG_STATE_SAVE_RESTORE_FLAG = "org.eclipse.debug.ui/debug/viewers/stateSaveRestore"; //$NON-NLS-1$
+	static final String DEBUG_PRESENTATION_ID_FLAG ="org.eclipse.debug.ui/debug/viewers/presentationId"; //$NON-NLS-1$
+	static final String DEBUG_DYNAMIC_LOADING_FLAG = "org.eclipse.debug.ui/debug/memory/dynamicLoading"; //$NON-NLS-1$
+	/**
+	 * The {@link DebugTrace} object to print to OSGi tracing
+	 * @since 3.8
+	 */
+	private static DebugTrace fgDebugTrace;
 	
 	/**
 	 * The singleton debug plug-in instance
@@ -203,9 +232,6 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	 */
 	private IPropertyChangeListener fThemeListener;
     
-	
-    public static boolean DEBUG = false;
-	
     /**
      * Dummy launch node representing a launch that is waiting
      * for a build to finish before proceeding. This node exists
@@ -254,17 +280,32 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	}
 	
 	/**
-	 * If the debug flag is set the specified message is printed to the console
-	 * @param message
+	 * Prints the given message to System.out and to the OSGi tracing (if started)
+	 * @param option the option or <code>null</code>
+	 * @param message the message to print or <code>null</code>
+	 * @param throwable the {@link Throwable} or <code>null</code>
+	 * @since 3.8
 	 */
-	public static void debug(String message) {
-		if (DEBUG) {
-			System.out.println(message);
+	public static void trace(String option, String message, Throwable throwable) {
+		System.out.println(message);
+		if(fgDebugTrace != null) {
+			fgDebugTrace.trace(option, message, throwable);
 		}
 	}
-		
+	
+	/**
+	 * Prints the given message to System.out and to the OSGi tracing (if enabled)
+	 * 
+	 * @param message the message or <code>null</code>
+	 * @since 3.8
+	 */
+	public static void trace(String message) {
+		trace(null, message, null);
+	}
+	
 	/**
 	 * Returns the singleton instance of the debug plug-in.
+	 * @return the singleton {@link DebugUIPlugin}
 	 */
 	public static DebugUIPlugin getDefault() {
 		if(fgDebugUIPlugin == null) {
@@ -275,6 +316,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	
 	/**
 	 * Convenience method which returns the unique identifier of this plug-in.
+	 * @return the identifier of the plug-in
 	 */
 	public static String getUniqueIdentifier() {
 		return IDebugUIConstants.PLUGIN_ID;
@@ -349,6 +391,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 
 	/**
 	 * Returns the default label provider for the debug UI.
+	 * @return the singleton {@link DefaultLabelProvider}
 	 */
 	public static ILabelProvider getDefaultLabelProvider() {
 		if (fgDefaultLabelProvider == null) {
@@ -365,6 +408,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	 * @param element the config element defining the extension
 	 * @param classAttribute the name of the attribute carrying the class
 	 * @return the extension object
+	 * @throws CoreException if an exception occurs
 	 */
 	public static Object createExtension(final IConfigurationElement element, final String classAttribute) throws CoreException {
 		// If plug-n has been loaded create extension.
@@ -441,7 +485,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 			
 			fSaveParticipants.clear();
 			
-			ResourcesPlugin.getWorkspace().removeSaveParticipant(this);
+			ResourcesPlugin.getWorkspace().removeSaveParticipant(getUniqueIdentifier());
 			
 			if (fThemeListener != null) {
 				if (PlatformUI.isWorkbenchRunning())
@@ -457,7 +501,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	/**
 	 * Add the specified <code>ISaveParticipant</code> to the current listing of
 	 * registered participants
-	 * @param participant
+	 * @param participant the save participant to add
 	 * @return true if this current listing did not already contain the specified participant
 	 * @since 3.3
 	 */
@@ -468,7 +512,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	/**
 	 * Removes the specified <code>ISaveParticipant</code> from the current listing of registered
 	 * participants
-	 * @param participant
+	 * @param participant the save participant to remove
 	 * @return true if the set contained the specified element
 	 * 
 	 * @since 3.3
@@ -477,15 +521,25 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 		return fSaveParticipants.remove(participant);
 	}
 	
-	/**
-	 * @see AbstractUIPlugin#startup()
+	/* (non-Javadoc)
+	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
 	 */
 	public void start(BundleContext context) throws Exception {
 		super.start(context);
-		ResourcesPlugin.getWorkspace().addSaveParticipant(this,
+		Hashtable props = new Hashtable(2);
+		props.put(org.eclipse.osgi.service.debug.DebugOptions.LISTENER_SYMBOLICNAME, getUniqueIdentifier());
+		context.registerService(DebugOptionsListener.class.getName(), this, props);
+		ResourcesPlugin.getWorkspace().addSaveParticipant(getUniqueIdentifier(),
 				new ISaveParticipant() {
 					public void saving(ISaveContext saveContext) throws CoreException {
-						savePluginPreferences();
+						IEclipsePreferences node = InstanceScope.INSTANCE.getNode(getUniqueIdentifier());
+						if(node != null) {
+							try {
+								node.flush();
+							} catch (BackingStoreException e) {
+								log(e);
+							}
+						}
 						for(Iterator iter = fSaveParticipants.iterator(); iter.hasNext();) {
 							((ISaveParticipant)iter.next()).saving(saveContext);
 						}
@@ -506,7 +560,6 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 						}
 					}
 				});
-		DEBUG = "true".equals(Platform.getDebugOption("org.eclipse.debug.ui/debug"));  //$NON-NLS-1$//$NON-NLS-2$
 		
 		// make sure the perspective manager is created
 		// and be the first debug event listener
@@ -558,8 +611,36 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 				});
 	}
 
+	/* (non-Javadoc)
+	 * @see org.eclipse.osgi.service.debug.DebugOptionsListener#optionsChanged(org.eclipse.osgi.service.debug.DebugOptions)
+	 */
+	public void optionsChanged(DebugOptions options) {
+		fgDebugTrace = options.newDebugTrace(getUniqueIdentifier());
+		DEBUG = options.getBooleanOption(DEBUG_FLAG, false);
+		DEBUG_BREAKPOINT_DELTAS = DEBUG && options.getBooleanOption(DEBUG_BREAKPOINT_DELTAS_FLAG, false);
+		DEBUG_MODEL = DEBUG && options.getBooleanOption(DEBUG_MODEL_FLAG, false);
+		DEBUG_VIEWER = DEBUG && options.getBooleanOption(DEBUG_VIEWER_FLAG, false);
+		DEBUG_BREADCRUMB = DEBUG && options.getBooleanOption(DEBUG_BREADCRUMB_FLAG, false);
+		DEBUG_TREE_VIEWER_DROPDOWN = DEBUG && options.getBooleanOption(DEBUG_TREE_VIEWER_DROPDOWN_FLAG, false);
+		DEBUG_CONTENT_PROVIDER = DEBUG && options.getBooleanOption(DEBUG_CONTENT_PROVIDER_FLAG, false);
+		DEBUG_UPDATE_SEQUENCE = DEBUG && options.getBooleanOption(DEBUG_UPDATE_SEQUENCE_FLAG, false);
+		DEBUG_DELTAS = DEBUG && options.getBooleanOption(DEBUG_DELTAS_FLAG, false);
+		DEBUG_STATE_SAVE_RESTORE = DEBUG && options.getBooleanOption(DEBUG_STATE_SAVE_RESTORE_FLAG, false);
+		DEBUG_DYNAMIC_LOADING = DEBUG && options.getBooleanOption(DEBUG_DYNAMIC_LOADING_FLAG, false);
+		if(DEBUG) {
+			DEBUG_PRESENTATION_ID = options.getOption(DEBUG_PRESENTATION_ID_FLAG, IInternalDebugCoreConstants.EMPTY_STRING);
+			if(IInternalDebugCoreConstants.EMPTY_STRING.equals(DEBUG_PRESENTATION_ID)) {
+				DEBUG_PRESENTATION_ID = null;
+			}
+		}
+	}
+	
 	/**
 	 * Utility method with conventions
+	 * @param shell the shell to open the dialog on
+	 * @param title the title of the dialog
+	 * @param message the message to display in the dialog
+	 * @param s the underlying {@link IStatus} to display
 	 */
 	public static void errorDialog(Shell shell, String title, String message, IStatus s) {
 		// if the 'message' resource string and the IStatus' message are the same,
@@ -572,6 +653,10 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	
 	/**
 	 * Utility method with conventions
+	 * @param shell the shell to open the dialog on
+	 * @param title the title for the dialog
+	 * @param message the message to display in the dialog
+	 * @param t the underlying exception for the dialog
 	 */
 	public static void errorDialog(Shell shell, String title, String message, Throwable t) {
 		IStatus status;
@@ -699,11 +784,10 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
      * Opens the {@link LaunchConfigurationsDialog} on the given selection for the given group. A status
      * can be provided or <code>null</code> and the dialog can initialize the given {@link ILaunchConfiguration}
      * to its defaults when opening as well - as long as the specified configuration is an {@link ILaunchConfigurationWorkingCopy}.
-     * @param shell
-     * @param selection
-     * @param groupIdentifier
-     * @param status
-     * @param setDefaults
+     * @param shell the shell to open the dialog on
+     * @param selection the non-null selection to show when the dialog opens
+     * @param groupIdentifier the identifier of the launch group to open the dialog on
+     * @param setDefaults if the default values should be set on the opened configuration - if there is one
      * @return the return code from the dialog.open() call
      * @since 3.6
      */
@@ -722,6 +806,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	/**
 	 * Save all dirty editors in the workbench.
 	 * Returns whether the operation succeeded.
+	 * @param confirm if the user should be asked before saving
 	 * 
 	 * @return whether all saving was completed
 	 * @deprecated Saving has been moved to the launch delegate <code>LaunchConfigurationDelegate</code> to allow for scoped saving
@@ -737,6 +822,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	/**
 	 * Save & build the workspace according to the user-specified preferences.  Return <code>false</code> if
 	 * any problems were encountered, <code>true</code> otherwise.
+	 * @return <code>false</code> if any problems were encountered, <code>true</code> otherwise.
 	 * 
 	 * @deprecated this method is no longer to be used. It is an artifact from 2.0, and all saving is now done with the
 	 * launch delegate <code>LaunchConfigurationDelegate</code>
@@ -787,7 +873,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	
 	/**
 	 * Returns the workbench's display.
-	 * 
+	 * @return the standard display 
 	 */
 	public static Display getStandardDisplay() {
 		return PlatformUI.getWorkbench().getDisplay();
@@ -800,6 +886,8 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	 * <li>CONSOLE_SYS_ERR_RGB</li>
 	 * <li>CONSOLE_SYS_IN_RGB</li>
 	 * <li>CHANGED_VARIABLE_RGB</li>
+	 * @param type the name of the type to ask for
+	 * @return the {@link Color}
 	 */
 	public static Color getPreferenceColor(String type) {
 		return ColorManager.getDefault().getColor(PreferenceConverter.getColor(getDefault().getPreferenceStore(), type));
@@ -861,7 +949,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	/**
 	 * Returns the perspective manager.
 	 * 
-	 * @return
+	 * @return the singleton {@link PerspectiveManager}
 	 */
 	public PerspectiveManager getPerspectiveManager() {
 		return fPerspectiveManager;
@@ -877,6 +965,28 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	 */
 	public void launchRemoved(ILaunch launch) {}
 
+	/**
+	 * Formats the given key stroke or click name and the modifier keys 
+	 * to a key binding string that can be used in action texts. 
+	 * 
+	 * @param modifierKeys the modifier keys
+	 * @param keyOrClick a key stroke or click, e.g. "Double Click"
+	 * @return the formatted keyboard shortcut string, e.g. "Shift+Double Click"
+	 * 
+	 * @since 3.8
+	 */
+	public static final String formatKeyBindingString(int modifierKeys, String keyOrClick) {
+		// this should actually all be delegated to KeyStroke class
+		return KeyStroke.getInstance(modifierKeys, KeyStroke.NO_KEY).format() + keyOrClick; 
+	}
+
+	public static boolean DEBUG_TEST_PRESENTATION_ID(IPresentationContext context) {
+	    if (context == null) {
+	        return true;
+	    }
+	    return DEBUG_PRESENTATION_ID == null || DEBUG_PRESENTATION_ID.equals(context.getId());
+	}
+
 	/**
      * Return the ILaunch associated with a model element, or null if there is
      * no such association.
@@ -1180,6 +1290,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 
 	/**
 	 * Returns the label with any accelerators removed.
+	 * @param label the label to remove accelerators from
 	 * 
 	 * @return label without accelerators
 	 */
@@ -1209,6 +1320,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 	/**
 	 * Returns the label with any DBCS accelerator moved to the end of the string.
 	 * See bug 186921.
+	 * @param label the label to be adjusted
 	 * 
 	 * @return label with moved accelerator
 	 */
@@ -1238,6 +1350,7 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
 
     /**
      * Returns the image descriptor registry used for this plug-in.
+     * @return the singleton {@link ImageDescriptorRegistry}
      * 
      * @since 3.1
      */
@@ -1252,8 +1365,8 @@ public class DebugUIPlugin extends AbstractUIPlugin implements ILaunchListener {
      * Returns an image descriptor for the icon referenced by the given attribute
      * and configuration element, or <code>null</code> if none.
      * 
-     * @param element
-     * @param attr
+     * @param element the configuration element
+     * @param attr the name of the attribute
      * @return image descriptor or <code>null</code>
      */
     public static ImageDescriptor getImageDescriptor(IConfigurationElement element, String attr) {
