@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2006 IBM Corporation and others.
+ * Copyright (c) 2000, 2011 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,6 +11,8 @@
 
 package org.eclipse.debug.internal.ui.commands.actions;
 
+import org.eclipse.jface.action.IAction;
+
 /**
  * Step over action delegate.
  * 
@@ -23,5 +25,9 @@ public class StepOverCommandActionDelegate extends DebugCommandActionDelegate {
         setAction(new StepOverCommandAction());
     }
 
+    public void init(IAction action) {
+        super.init(action);
+    }
+    
     
 }
