@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2011 IBM Corporation and others.
+ * Copyright (c) 2007, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,6 +10,7 @@
  *     Cloudsmith - https://bugs.eclipse.org/bugs/show_bug.cgi?id=226401
  *     EclipseSource - ongoing development
  *     Sonatype, Inc. - ongoing development
+ *     Pascal Rapicault - Support for bundled macosx http://bugs.eclipse.org/57349
  *******************************************************************************/
 package org.eclipse.equinox.internal.p2.director.app;
 
@@ -24,16 +25,21 @@ import org.eclipse.equinox.app.IApplication;
 import org.eclipse.equinox.app.IApplicationContext;
 import org.eclipse.equinox.internal.p2.core.helpers.*;
 import org.eclipse.equinox.internal.p2.director.ProfileChangeRequest;
+import org.eclipse.equinox.internal.provisional.p2.core.eventbus.IProvisioningEventBus;
+import org.eclipse.equinox.internal.provisional.p2.core.eventbus.ProvisioningListener;
 import org.eclipse.equinox.internal.provisional.p2.director.IDirector;
 import org.eclipse.equinox.internal.provisional.p2.director.PlanExecutionHelper;
+import org.eclipse.equinox.internal.provisional.p2.repository.RepositoryEvent;
 import org.eclipse.equinox.p2.core.*;
 import org.eclipse.equinox.p2.engine.*;
 import org.eclipse.equinox.p2.engine.query.UserVisibleRootQuery;
 import org.eclipse.equinox.p2.metadata.*;
 import org.eclipse.equinox.p2.metadata.Version;
+import org.eclipse.equinox.p2.metadata.VersionRange;
 import org.eclipse.equinox.p2.planner.IPlanner;
 import org.eclipse.equinox.p2.planner.IProfileChangeRequest;
 import org.eclipse.equinox.p2.query.*;
+import org.eclipse.equinox.p2.repository.IRepository;
 import org.eclipse.equinox.p2.repository.artifact.IArtifactRepositoryManager;
 import org.eclipse.equinox.p2.repository.metadata.IMetadataRepositoryManager;
 import org.eclipse.osgi.framework.log.FrameworkLog;
@@ -42,8 +48,8 @@ import org.eclipse.osgi.util.NLS;
 import org.osgi.framework.*;
 import org.osgi.service.packageadmin.PackageAdmin;
 
-public class DirectorApplication implements IApplication {
-	class AvoidTrustPromptService extends UIServices {
+public class DirectorApplication implements IApplication, ProvisioningListener {
+	public static class AvoidTrustPromptService extends UIServices {
 		@Override
 		public AuthenticationInfo getUsernamePassword(String location) {
 			return null;
@@ -55,8 +61,17 @@ public class DirectorApplication implements IApplication {
 		}
 
 		@Override
-		public TrustInfo getTrustInfo(Certificate[][] untrustedChain, String[] unsignedDetail) {
-			return new TrustInfo(null, false, true);
+		public TrustInfo getTrustInfo(Certificate[][] untrustedChains, String[] unsignedDetail) {
+			final Certificate[] trusted;
+			if (untrustedChains == null) {
+				trusted = null;
+			} else {
+				trusted = new Certificate[untrustedChains.length];
+				for (int i = 0; i < untrustedChains.length; i++) {
+					trusted[i] = untrustedChains[i][0];
+				}
+			}
+			return new TrustInfo(trusted, false, true);
 		}
 	}
 
@@ -481,6 +496,9 @@ public class DirectorApplication implements IApplication {
 				props.put(IProfile.PROP_ROAMING, Boolean.TRUE.toString());
 
 			String env = getEnvironmentProperty();
+			//Detect the desire to have a bundled mac application and tweak the environemtn
+			if (org.eclipse.osgi.service.environment.Constants.OS_MACOSX.equals(os) && destination.getName().endsWith(".app")) //$NON-NLS-1$
+				env += ',' + org.eclipse.equinox.p2.core.spi.Constants.MACOSX_BUNDLED + "=true"; //$NON-NLS-1$
 			if (env != null)
 				props.put(IProfile.PROP_ENVIRONMENTS, env);
 			if (profileProperties != null)
@@ -607,6 +625,50 @@ public class DirectorApplication implements IApplication {
 			throw new ProvisionException(Messages.Missing_Engine);
 
 		targetAgent.registerService(UIServices.SERVICE_NAME, new AvoidTrustPromptService());
+
+		// TODO do we only want to do this if we are provisioning to ourself?
+		IProvisioningEventBus eventBus = (IProvisioningEventBus) targetAgent.getService(IProvisioningEventBus.SERVICE_NAME);
+		if (eventBus == null)
+			return;
+		eventBus.addListener(this);
+
+	}
+
+	/* (non-Javadoc)
+	 * @see org.eclipse.equinox.internal.provisional.p2.core.eventbus.ProvisioningListener#notify(java.util.EventObject)
+	 * 
+	 * See bug: https://bugs.eclipse.org/340971
+	 * Using the event bus to detect whether or not a repository was added in a touchpoint action. 
+	 * If it was, then (if it exists) remove it from our list of repos to remove after we complete our install.
+	 */
+	public void notify(EventObject o) {
+		if (!(o instanceof RepositoryEvent))
+			return;
+		RepositoryEvent event = (RepositoryEvent) o;
+		if (RepositoryEvent.ADDED != event.getKind())
+			return;
+		int type = event.getRepositoryType();
+		URI location = event.getRepositoryLocation();
+		if (IRepository.TYPE_ARTIFACT == type) {
+			for (int i = 0; i < artifactReposForRemoval.length; i++) {
+				if (artifactReposForRemoval[i] != null && URIUtil.sameURI(artifactReposForRemoval[i], (location))) {
+					artifactReposForRemoval[i] = null;
+					break;
+				}
+			}
+			// either found or not found. either way, we're done here
+			return;
+		}
+		if (IRepository.TYPE_METADATA == type) {
+			for (int i = 0; i < metadataReposForRemoval.length; i++) {
+				if (metadataReposForRemoval[i] != null && URIUtil.sameURI(metadataReposForRemoval[i], (location))) {
+					metadataReposForRemoval[i] = null;
+					break;
+				}
+			}
+			// either found or not found. either way, we're done here
+			return;
+		}
 	}
 
 	private void logStatus(IStatus status) {
@@ -1217,6 +1279,9 @@ public class DirectorApplication implements IApplication {
 	}
 
 	public void stop() {
+		IProvisioningEventBus eventBus = (IProvisioningEventBus) targetAgent.getService(IProvisioningEventBus.SERVICE_NAME);
+		if (eventBus != null)
+			eventBus.removeListener(this);
 		if (log != null)
 			log.close();
 	}
