@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -40,7 +40,9 @@ import org.eclipse.jdt.core.dom.ClassInstanceCreation;
 import org.eclipse.jdt.core.dom.EnumDeclaration;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.FieldAccess;
+import org.eclipse.jdt.core.dom.IAnnotationBinding;
 import org.eclipse.jdt.core.dom.IBinding;
+import org.eclipse.jdt.core.dom.IMemberValuePairBinding;
 import org.eclipse.jdt.core.dom.IMethodBinding;
 import org.eclipse.jdt.core.dom.IPackageBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
@@ -605,7 +607,7 @@ public class Bindings {
 	 * Tests whether the two methods are erasure-equivalent.
 	 * @param method the first method
 	 * @param methodName the name of the second method
-	 * @param parameters the parameters of the second parameters
+	 * @param parameters the parameters of the second method
 	 * @return return <code>true</code> if the two bindings are equal
 	 * @deprecated use {@link #isSubsignature(IMethodBinding, IMethodBinding)}
 	 */
@@ -772,14 +774,20 @@ public class Bindings {
 		for (int i= 0; i < parameters.length; i++) {
 			first= parameters[i];
 			index= first.indexOf('<');
-			if (index > 0)
-				first= first.substring(0, index);
-			second= methodParameters[i].getErasure().getQualifiedName();
-			index= second.indexOf('<');
-			if (index > 0)
-				second= second.substring(0, index);
-			if (!first.equals(second))
-				return false;
+			if (index > 0){
+				int lastIndex= first.lastIndexOf('>');
+				StringBuffer buf= new StringBuffer();
+				buf.append(first.substring(0, index));
+				if (lastIndex < first.length() - 1)
+					buf.append(first.substring(lastIndex + 1, first.length()));
+				first= buf.toString();
+			}
+			second= methodParameters[i].getQualifiedName();
+			if (!first.equals(second)) {
+				second= methodParameters[i].getErasure().getQualifiedName();
+				if (!first.equals(second))
+					return false;
+			}
 		}
 		return true;
 	}
@@ -795,7 +803,7 @@ public class Bindings {
 		if (hierarchyType.isArray() || hierarchyType.isPrimitive()) {
 			return null;
 		}
-		if (fullyQualifiedTypeName.equals(hierarchyType.getQualifiedName())) {
+		if (fullyQualifiedTypeName.equals(hierarchyType.getTypeDeclaration().getQualifiedName())) {
 			return hierarchyType;
 		}
 		ITypeBinding superClass= hierarchyType.getSuperclass();
@@ -1370,7 +1378,7 @@ public class Bindings {
 	 * @param goIntoCast iff <code>true</code>, go into a CastExpression's expression to resolve
 	 * @return the expression binding, or <code>null</code> if the expression has no binding or the
 	 *         binding could not be resolved
-	 *         
+	 * 
 	 * @see StubUtility#getVariableNameSuggestions(int, IJavaProject, ITypeBinding, Expression, java.util.Collection)
 	 * @since 3.5
 	 */
@@ -1419,4 +1427,22 @@ public class Bindings {
 		}
 	}
 
+	public static boolean isClassOrRuntimeAnnotation(ITypeBinding annotationType) {
+		IAnnotationBinding[] metaAnnotations= annotationType.getAnnotations();
+		for (IAnnotationBinding metaAnnotation : metaAnnotations) {
+			if ("java.lang.annotation.Retention".equals(metaAnnotation.getAnnotationType().getQualifiedName())) { //$NON-NLS-1$
+				IMemberValuePairBinding[] mvps= metaAnnotation.getDeclaredMemberValuePairs();
+				if (mvps.length == 1) {
+					Object value= mvps[0].getValue();
+					if (value instanceof IVariableBinding) {
+						String name= ((IVariableBinding) value).getName();
+						if ("RUNTIME".equals(name) || "CLASS".equals(name)) //$NON-NLS-1$ //$NON-NLS-2$
+							return true;
+					}
+				}
+			}
+		}
+		return false;
+	}
+
 }
