@@ -978,24 +978,48 @@ public class RenameTypeProcessor extends JavaRenameProcessor implements ITextUpd
 			return result;
 		ICompilationUnit[] 	cusWithReferencesToRenamedType= getCus(fReferences);
 
-		ICompilationUnit[] intersection= isIntersectionEmpty(cusWithReferencesToRenamedType, cusWithReferencesToConflictingTypes);
-		if (intersection.length == 0)
-			return result;
-
-		for (int i= 0; i < intersection.length; i++) {
-			RefactoringStatusContext context= JavaStatusContext.create(intersection[i]);
+		Set<ICompilationUnit> conflicts= getIntersection(cusWithReferencesToRenamedType, cusWithReferencesToConflictingTypes);
+		if (cusWithReferencesToConflictingTypes.length > 0) {
+			cus: for (ICompilationUnit cu : cusWithReferencesToConflictingTypes) {
+				String packageName= fType.getPackageFragment().getElementName();
+				if (((IPackageFragment) cu.getParent()).getElementName().equals(packageName)) {
+					boolean hasOnDemandImport= false;
+					IImportDeclaration[] imports= cu.getImports();
+					for (IImportDeclaration importDecl : imports) {
+						if (importDecl.isOnDemand()) {
+							hasOnDemandImport= true;
+						} else {
+							String importName= importDecl.getElementName();
+							int packageLength= importName.length() - getNewElementName().length() - 1;
+							if (packageLength > 0
+									&& importName.endsWith(getNewElementName())
+									&& importName.charAt(packageLength) == '.') {
+								continue cus; // explicit import from another package => no problem
+							}
+						}
+					}
+					if (hasOnDemandImport) {
+						// the renamed type in the same package will shadow the *-imported type
+						conflicts.add(cu);
+					}
+				}
+			}
+		}
+		
+		for (ICompilationUnit conflict : conflicts) {
+			RefactoringStatusContext context= JavaStatusContext.create(conflict);
 			String message= Messages.format(RefactoringCoreMessages.RenameTypeRefactoring_another_type,
-				new String[] { getNewElementLabel(), BasicElementLabels.getFileName(intersection[i])});
+				new String[] { getNewElementLabel(), BasicElementLabels.getFileName(conflict)});
 			result.addError(message, context);
 		}
 		return result;
 	}
 
-	private static ICompilationUnit[] isIntersectionEmpty(ICompilationUnit[] a1, ICompilationUnit[] a2){
+	private static Set<ICompilationUnit> getIntersection(ICompilationUnit[] a1, ICompilationUnit[] a2){
 		Set<ICompilationUnit> set1= new HashSet<ICompilationUnit>(Arrays.asList(a1));
 		Set<ICompilationUnit> set2= new HashSet<ICompilationUnit>(Arrays.asList(a2));
 		set1.retainAll(set2);
-		return set1.toArray(new ICompilationUnit[set1.size()]);
+		return set1;
 	}
 
 	private static ICompilationUnit[] getCus(SearchResultGroup[] searchResultGroups){
