@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2011 IBM Corporation and others.
+ * Copyright (c) 2005, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -7,6 +7,8 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Paul Fullbright <paul.fullbright@oracle.com> - content assist category enablement - http://bugs.eclipse.org/345213
+ *     Marcel Bruch <bruch@cs.tu-darmstadt.de> - [content assist] Allow to re-sort proposals - https://bugs.eclipse.org/bugs/show_bug.cgi?id=350991
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.text.java;
 
@@ -17,6 +19,12 @@ import java.util.List;
 
 import org.osgi.framework.Bundle;
 
+import org.eclipse.core.expressions.EvaluationContext;
+import org.eclipse.core.expressions.EvaluationResult;
+import org.eclipse.core.expressions.Expression;
+import org.eclipse.core.expressions.ExpressionConverter;
+import org.eclipse.core.expressions.ExpressionTagNames;
+
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.IConfigurationElement;
@@ -33,6 +41,8 @@ import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.text.contentassist.ICompletionProposal;
 import org.eclipse.jface.text.contentassist.IContextInformation;
 
+import org.eclipse.jdt.core.IJavaProject;
+
 import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.ui.text.java.ContentAssistInvocationContext;
@@ -40,6 +50,7 @@ import org.eclipse.jdt.ui.text.java.IJavaCompletionProposalComputer;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
+
 /**
  * Describes a category extension to the "javaCompletionProposalComputer" extension point.
  *
@@ -54,6 +65,9 @@ public final class CompletionProposalCategory {
 	private final IConfigurationElement fElement;
 	/** The image descriptor for this category, or <code>null</code> if none specified. */
 	private final ImageDescriptor fImage;
+	
+	/** The enablement expression for this category, or <code>null</code> if none specified. */
+	private final Expression fEnablementExpression;
 
 	private boolean fIsSeparateCommand= true;
 	private boolean fIsEnabled= true;
@@ -63,6 +77,15 @@ public final class CompletionProposalCategory {
 	private int fSortOrder= 0xffff - 1;
 	private String fLastError= null;
 
+	/**
+	 * Flag indicating whether any completion engine associated with this category requests
+	 * resorting of its proposals after filtering is triggered. Filtering is, e.g., triggered when a
+	 * user continues typing with an open completion window.
+	 * 
+	 * @since 3.8
+	 */
+	private boolean fNeedsSortingAfterFiltering;
+
 	CompletionProposalCategory(IConfigurationElement element, CompletionProposalComputerRegistry registry) throws CoreException {
 		fElement= element;
 		fRegistry= registry;
@@ -74,7 +97,16 @@ public final class CompletionProposalCategory {
 			fName= fId;
 		else
 			fName= name;
-
+		
+		IConfigurationElement[] children= fElement.getChildren(ExpressionTagNames.ENABLEMENT);
+		if (children.length == 1) {
+			ExpressionConverter parser= ExpressionConverter.getDefault();
+			fEnablementExpression = parser.perform(children[0]);
+		}
+		else {
+			fEnablementExpression = null;
+		}
+		
 		String icon= element.getAttribute(ICON);
 		ImageDescriptor img= null;
 		if (icon != null) {
@@ -94,6 +126,7 @@ public final class CompletionProposalCategory {
 		fId= id;
 		fName= name;
 		fElement= null;
+		fEnablementExpression = null;
 		fImage= null;
 	}
 
@@ -137,6 +170,16 @@ public final class CompletionProposalCategory {
 		return fName;
 	}
 
+	/**
+	 * Returns the enablement element of the described extension.
+	 * 
+	 * @return the enablement expression or <code>null</code> if it is not specified
+	 * @since 3.8.1
+	 */
+	Expression getEnablementExpression() {
+		return fEnablementExpression;
+	}
+
 	/**
 	 * Returns the name of the described extension
 	 * without mnemonic hint in order to be displayed
@@ -245,6 +288,36 @@ public final class CompletionProposalCategory {
 	public void setSortOrder(int sortOrder) {
 		fSortOrder= sortOrder;
 	}
+	
+	/**
+	 * Determines if the project matches any enablement expression defined on the extension.
+	 * 
+	 * @param javaProject the Java project against which to test the enablement expression, can be
+	 *            <code>null</code>
+	 * @return <code>true</code> if any enablement expression matches the given project or if the
+	 *         project is <code>null</code> or no enablement expression is specified,
+	 *         <code>false</code> otherwise
+	 * @since 3.8
+	 */
+	public boolean matches(IJavaProject javaProject) {
+		if (fEnablementExpression == null) {
+			return true;
+		}
+		
+		if (javaProject == null) {
+			return false;
+		}
+		
+		try {
+			EvaluationContext evalContext= new EvaluationContext(null, javaProject);
+			evalContext.addVariable("project", javaProject); //$NON-NLS-1$
+			return fEnablementExpression.evaluate(evalContext) == EvaluationResult.TRUE;
+		} catch (CoreException e) {
+			JavaPlugin.log(e);
+		}
+		
+		return false;
+	}
 
 	/**
 	 * Safely computes completion proposals of all computers of this category through their
@@ -312,8 +385,10 @@ public final class CompletionProposalCategory {
 		List<CompletionProposalComputerDescriptor> descriptors= new ArrayList<CompletionProposalComputerDescriptor>(fRegistry.getProposalComputerDescriptors());
 		for (Iterator<CompletionProposalComputerDescriptor> it= descriptors.iterator(); it.hasNext();) {
 			CompletionProposalComputerDescriptor desc= it.next();
-			if (desc.getCategory() == this)
+			if (desc.getCategory() == this){
 				desc.sessionStarted();
+				fNeedsSortingAfterFiltering= fNeedsSortingAfterFiltering || desc.isSortingAfterFilteringNeeded();
+		    }
 			if (fLastError == null)
 				fLastError= desc.getErrorMessage();
 		}
@@ -323,6 +398,7 @@ public final class CompletionProposalCategory {
 	 * Notifies the computers in this category of a proposal computation session end.
 	 */
 	public void sessionEnded() {
+		fNeedsSortingAfterFiltering= false;
 		List<CompletionProposalComputerDescriptor> descriptors= new ArrayList<CompletionProposalComputerDescriptor>(fRegistry.getProposalComputerDescriptors());
 		for (Iterator<CompletionProposalComputerDescriptor> it= descriptors.iterator(); it.hasNext();) {
 			CompletionProposalComputerDescriptor desc= it.next();
@@ -333,4 +409,14 @@ public final class CompletionProposalCategory {
 		}
 	}
 
+	/**
+	 * Returns whether any completion proposal computer associated with this category requires
+	 * proposals to be sorted again after filtering.
+	 * 
+	 * @return <code>true</code> if any completion proposal computer in this category requires
+	 *         proposals to be sorted.
+	 */
+	public boolean isSortingAfterFilteringNeeded() {
+		return fNeedsSortingAfterFiltering;
+	}
 }
