@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -33,10 +33,10 @@ import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.JavaModelException;
 
-import org.eclipse.jdt.ui.JavaUI;
 import org.eclipse.jdt.ui.text.java.hover.IJavaEditorTextHover;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
+import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
 import org.eclipse.jdt.internal.ui.javaeditor.IClassFileEditorInput;
 import org.eclipse.jdt.internal.ui.javaeditor.WorkingCopyManager;
 import org.eclipse.jdt.internal.ui.text.JavaWordFinder;
@@ -152,8 +152,10 @@ public abstract class AbstractJavaEditorTextHover implements IJavaEditorTextHove
 		};
 	}
 
-	/*
-	 * @see org.eclipse.jface.text.information.IInformationProviderExtension2#getInformationPresenterControlCreator()
+	/**
+	 * Delegate method for {@link JavaInformationProvider#getInformationPresenterControlCreator()}
+	 * 
+	 * @return the information control creator or null if none is available
 	 * @since 3.4
 	 */
 	public IInformationControlCreator getInformationPresenterControlCreator() {
@@ -167,7 +169,7 @@ public abstract class AbstractJavaEditorTextHover implements IJavaEditorTextHove
 	protected ITypeRoot getEditorInputJavaElement() {
 		IEditorPart editor= getEditor();
 		if (editor != null)
-			return JavaUI.getEditorInputTypeRoot(editor.getEditorInput());
+			return EditorUtility.getEditorInputJavaElement(editor, false);
 		return null;
 	}
 }
