@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -1035,7 +1035,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 			public void controlMoved(ControlEvent e) {
 			}
 			public void controlResized(ControlEvent e) {
-				if (getViewLayout() == VIEW_LAYOUT_AUTOMATIC && !fInComputeLayout) {
+				int viewLayout= getViewLayout();
+				if ((viewLayout == VIEW_LAYOUT_AUTOMATIC || viewLayout == -1) && !fInComputeLayout) {
 					setViewLayout(VIEW_LAYOUT_AUTOMATIC);
 				}
 			}
@@ -1074,6 +1075,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 										size.y -= viewFormToolbar.getSize().y;
 									}
 									horizontal= size.x > size.y;
+								} else if (size.x == 0 && size.y == 0) {
+									return;
 								}
 							}
 							if (fCurrentLayout == VIEW_LAYOUT_AUTOMATIC) {
