@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2011 EclipseSource Inc. and others.
+ * Copyright (c) 2010, 2012 EclipseSource Inc. and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,6 @@ package org.eclipse.pde.internal.core.target;
 
 import java.io.File;
 import java.net.URI;
-import java.net.URISyntaxException;
 import java.util.*;
 import org.eclipse.core.runtime.*;
 import org.eclipse.core.runtime.preferences.IPreferencesService;
@@ -34,8 +33,8 @@ import org.eclipse.equinox.p2.repository.*;
 import org.eclipse.equinox.p2.repository.artifact.*;
 import org.eclipse.equinox.p2.repository.metadata.IMetadataRepositoryManager;
 import org.eclipse.osgi.util.NLS;
+import org.eclipse.pde.core.target.*;
 import org.eclipse.pde.internal.core.PDECore;
-import org.eclipse.pde.internal.core.target.provisional.*;
 import org.osgi.framework.*;
 
 public class P2TargetUtils {
@@ -100,7 +99,12 @@ public class P2TargetUtils {
 	static final String PROP_AUTO_INCLUDE_SOURCE = PDECore.PLUGIN_ID + ".autoIncludeSource"; //$NON-NLS-1$	
 
 	/**
-	 * Table mapping target location to synchronizer (P2TargetUtils) instance.
+	 * Profile property that tracks whether or not the configuration phase should be executed when installing
+	 */
+	static final String PROP_INCLUDE_CONFIGURE_PHASE = PDECore.PLUGIN_ID + ".includeConfigure"; //$NON-NLS-1$
+
+	/**
+	 * Table mapping {@link ITargetDefinition} to synchronizer (P2TargetUtils) instance.
 	 */
 	private static Map synchronizers = new HashMap();
 
@@ -133,23 +137,24 @@ public class P2TargetUtils {
 	 * Whether this container should download and include source bundles for the selected units if the associated
 	 * source is available in the repository.
 	 * <p>
-	 * <code>false</code>by default
+	 * <code>false</code> by default
+	 * </p>
 	 */
 	private boolean fIncludeSource = false;
 
+	/**
+	 * Whether this container should execute the configure phase when installing the IUs
+	 * <p>
+	 * <code>false</code> by default
+	 * </p>
+	 */
+	private boolean fIncludeConfigurePhase = false;
+
 	/**
 	 * Whether or not this synchronizer is dirty by means other than target tweaks etc.
 	 */
 	private boolean fDirty = false;
 
-	public P2TargetUtils(ITargetDefinition target) {
-		try {
-			synchronizers.put(target.getHandle().getMemento(), this);
-		} catch (CoreException e) {
-			// This should never happen
-		}
-	}
-
 	/**
 	 * Deletes any profiles associated with target definitions that no longer exist
 	 * and returns a list of profile identifiers that were deleted.
@@ -483,6 +488,10 @@ public class P2TargetUtils {
 			return false;
 		}
 
+		if (getIncludeConfigurePhase() != Boolean.valueOf(fProfile.getProperty(PROP_INCLUDE_CONFIGURE_PHASE)).booleanValue()) {
+			return false;
+		}
+
 		// check top level IU's. If any have been removed from the containers that are
 		// still in the profile, we need to recreate (rather than uninstall)
 		IUProfilePropertyQuery propertyQuery = new IUProfilePropertyQuery(PROP_INSTALLED_IU, Boolean.toString(true));
@@ -493,7 +502,7 @@ public class P2TargetUtils {
 			IInstallableUnit unit = (IInstallableUnit) iterator.next();
 			installedIUs.add(new NameVersionDescriptor(unit.getId(), unit.getVersion().toString()));
 		}
-		IBundleContainer[] containers = target.getBundleContainers();
+		ITargetLocation[] containers = target.getTargetLocations();
 		if (containers == null) {
 			return installedIUs.isEmpty();
 		}
@@ -595,6 +604,24 @@ public class P2TargetUtils {
 		return fIncludeSource;
 	}
 
+	/**
+	 * Set whether or not the configuration phase should be executed when installing the IUs
+	 * 
+	 * @param value whether or not to execute configuration phase
+	 */
+	public void setIncludeConfigurePhase(boolean value) {
+		fIncludeConfigurePhase = value;
+	}
+
+	/**
+	 * Returns whether or not the configuration phase should be executed when installing the IUs
+	 * 
+	 * @return whether or not to execute configuration phase
+	 */
+	public boolean getIncludeConfigurePhase() {
+		return fIncludeConfigurePhase;
+	}
+
 	/**
 	 * Return whether or not the given target has a matching profile that is in sync
 	 * @param target the target to check
@@ -624,19 +651,13 @@ public class P2TargetUtils {
 	 * @return the discovered or created synchronizer
 	 */
 	static synchronized P2TargetUtils getSynchronizer(ITargetDefinition target) {
-		try {
-			String memento = target.getHandle().getMemento();
-			P2TargetUtils result = (P2TargetUtils) synchronizers.get(memento);
-			if (result != null)
-				return result;
-
-			result = new P2TargetUtils(target);
-			synchronizers.put(memento, result);
+		P2TargetUtils result = (P2TargetUtils) synchronizers.get(target);
+		if (result != null)
 			return result;
-		} catch (CoreException e) {
-			// Should never happen
-			throw new IllegalStateException(e.toString());
-		}
+
+		result = new P2TargetUtils();
+		synchronizers.put(target, result);
+		return result;
 	}
 
 	/**
@@ -719,6 +740,7 @@ public class P2TargetUtils {
 		properties.put(PROP_PROVISION_MODE, getProvisionMode(target));
 		properties.put(PROP_ALL_ENVIRONMENTS, Boolean.toString(getIncludeAllEnvironments()));
 		properties.put(PROP_AUTO_INCLUDE_SOURCE, Boolean.toString(getIncludeSource()));
+		properties.put(PROP_INCLUDE_CONFIGURE_PHASE, Boolean.toString(getIncludeConfigurePhase()));
 		fProfile = registry.addProfile(getProfileId(target), properties);
 	}
 
@@ -730,10 +752,10 @@ public class P2TargetUtils {
 		// the container caches (e.g., featureModels)
 		((TargetDefinition) target).flushCaches(P2TargetUtils.BUNDLE_POOL.toOSString());
 		// Now proactively recompute all the related container caches.
-		IBundleContainer[] containers = target.getBundleContainers();
+		ITargetLocation[] containers = target.getTargetLocations();
 		if (containers != null) {
 			for (int i = 0; i < containers.length; i++) {
-				IBundleContainer container = containers[i];
+				ITargetLocation container = containers[i];
 				if (container instanceof IUBundleContainer) {
 					((IUBundleContainer) container).synchronizerChanged(target);
 				}
@@ -927,9 +949,13 @@ public class P2TargetUtils {
 		plan.setProfileProperty(PROP_PROVISION_MODE, mode);
 		plan.setProfileProperty(PROP_ALL_ENVIRONMENTS, Boolean.toString(getIncludeAllEnvironments()));
 		plan.setProfileProperty(PROP_AUTO_INCLUDE_SOURCE, Boolean.toString(getIncludeSource()));
+		plan.setProfileProperty(PROP_INCLUDE_CONFIGURE_PHASE, Boolean.toString(getIncludeConfigurePhase()));
 		plan.setProfileProperty(PROP_SEQUENCE_NUMBER, Integer.toString(((TargetDefinition) definition).getSequenceNumber()));
 	}
 
+	/**
+	 * @return the phase set to execute, includes the configuration phase if {@link #getIncludeConfigurePhase()} is <code>true<code>
+	 */
 	private IPhaseSet createPhaseSet() {
 		ArrayList phases = new ArrayList(4);
 		phases.add(new Collect(100));
@@ -937,6 +963,10 @@ public class P2TargetUtils {
 		phases.add(new Uninstall(50, true));
 		phases.add(new Install(50));
 		phases.add(new CollectNativesPhase(100));
+		if (getIncludeConfigurePhase()) {
+			phases.add(new Configure(100));
+		}
+
 		return new PhaseSet((Phase[]) phases.toArray(new Phase[phases.size()]));
 	}
 
@@ -1020,7 +1050,8 @@ public class P2TargetUtils {
 			if (profileIU.satisfies(bundleRequirement)) {
 				String id = profileIU.getId() + ".source"; //$NON-NLS-1$
 				Version version = profileIU.getVersion();
-				VersionRange range = new VersionRange(version, true, version, true);
+				// use fully qualified name to avoid conflict with other VersionRange class
+				org.eclipse.equinox.p2.metadata.VersionRange range = new org.eclipse.equinox.p2.metadata.VersionRange(version, true, version, true);
 				IRequirement sourceRequirement = MetadataFactory.createRequirement("osgi.bundle", id, range, null, true, false, true); //$NON-NLS-1$
 				requirements.add(sourceRequirement);
 			}
@@ -1186,10 +1217,10 @@ public class P2TargetUtils {
 	 */
 	private URI[] getArtifactRepositories(ITargetDefinition target) throws CoreException {
 		Set result = new HashSet();
-		IBundleContainer[] containers = target.getBundleContainers();
+		ITargetLocation[] containers = target.getTargetLocations();
 		IArtifactRepositoryManager manager = getArtifactRepositoryManager();
 		for (int i = 0; i < containers.length; i++) {
-			IBundleContainer container = containers[i];
+			ITargetLocation container = containers[i];
 			if (container instanceof IUBundleContainer) {
 				URI[] repos = ((IUBundleContainer) container).getRepositories();
 				if (repos == null) {
@@ -1233,15 +1264,9 @@ public class P2TargetUtils {
 			return;
 		String[] recents = recent.split("\n"); //$NON-NLS-1$
 		for (int i = 0; i < recents.length; i++) {
-			String bundlePool = recents[i] + "/.metadata/.plugins/org.eclipse.pde.core/.bundle_pool"; //$NON-NLS-1$
-			if (new File(bundlePool).exists()) {
-				URI uri;
-				try {
-					uri = new URI("file", bundlePool, null); //$NON-NLS-1$
-					additionalRepos.add(uri);
-				} catch (URISyntaxException e) {
-					// should never happen
-				}
+			File bundlePool = new File(recents[i] + "/.metadata/.plugins/org.eclipse.pde.core/.bundle_pool"); //$NON-NLS-1$
+			if (bundlePool.exists()) {
+				additionalRepos.add(bundlePool.toURI().normalize());
 			}
 		}
 	}
@@ -1291,9 +1316,9 @@ public class P2TargetUtils {
 	 */
 	private IInstallableUnit[] getRootIUs(ITargetDefinition definition) throws CoreException {
 		HashSet result = new HashSet();
-		IBundleContainer[] containers = definition.getBundleContainers();
+		ITargetLocation[] containers = definition.getTargetLocations();
 		for (int i = 0; i < containers.length; i++) {
-			IBundleContainer container = containers[i];
+			ITargetLocation container = containers[i];
 			if (container instanceof IUBundleContainer) {
 				IUBundleContainer iuContainer = (IUBundleContainer) container;
 				IQueryable repos = getQueryableMetadata(iuContainer.getRepositories(), new NullProgressMonitor());
@@ -1320,10 +1345,10 @@ public class P2TargetUtils {
 	 */
 	private URI[] getMetadataRepositories(ITargetDefinition target) throws CoreException {
 		Set result = new HashSet();
-		IBundleContainer[] containers = target.getBundleContainers();
+		ITargetLocation[] containers = target.getTargetLocations();
 		IMetadataRepositoryManager manager = getRepoManager();
 		for (int i = 0; i < containers.length; i++) {
-			IBundleContainer container = containers[i];
+			ITargetLocation container = containers[i];
 			if (container instanceof IUBundleContainer) {
 				URI[] repos = ((IUBundleContainer) container).getRepositories();
 				if (repos == null) {
