@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2011 IBM Corporation and others.
+ * Copyright (c) 2006, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -462,15 +462,24 @@ public class JUnitLaunchConfigurationDelegate extends org.eclipse.jdt.junit.laun
 		if (fWorkspaceLocation == null) {
 			fWorkspaceLocation = LaunchArgumentsHelper.getWorkspaceLocation(configuration);
 		}
+
+		SubMonitor subMon = SubMonitor.convert(monitor, 50);
+
 		// Clear workspace and prompt, if necessary
-		if (!LauncherUtils.clearWorkspace(configuration, fWorkspaceLocation, new SubProgressMonitor(monitor, 1))) {
-			monitor.setCanceled(true);
-			return;
+		if (!LauncherUtils.clearWorkspace(configuration, fWorkspaceLocation, subMon.newChild(25))) {
+			throw new CoreException(Status.CANCEL_STATUS);
+		}
+
+		subMon.setWorkRemaining(25);
+		if (subMon.isCanceled()) {
+			throw new CoreException(Status.CANCEL_STATUS);
 		}
 
 		// clear config area, if necessary
 		if (configuration.getAttribute(IPDELauncherConstants.CONFIG_CLEAR_AREA, false))
-			CoreUtility.deleteContent(getConfigurationDirectory(configuration));
+			CoreUtility.deleteContent(getConfigurationDirectory(configuration), subMon.newChild(25));
+
+		subMon.done();
 	}
 
 	/**
