@@ -15,7 +15,7 @@
  *
  * IBM
  * -  Binding to permit interfacing between Cairo and SWT
- * -  Copyright (C) 2005, 2010 IBM Corp.  All Rights Reserved.
+ * -  Copyright (C) 2005, 2012 IBM Corp.  All Rights Reserved.
  *
  * ***** END LICENSE BLOCK ***** */
 
@@ -28,7 +28,17 @@
 #define LIB_CAIRO "libcairo.so.2"
 #endif
 
+#define cairo_format_stride_for_width_LIB LIB_CAIRO
 #define cairo_pdf_surface_set_size_LIB LIB_CAIRO
 #define cairo_ps_surface_set_size_LIB LIB_CAIRO
 #define cairo_surface_set_fallback_resolution_LIB LIB_CAIRO
 #define cairo_surface_get_type_LIB LIB_CAIRO
+#define cairo_image_surface_get_data_LIB LIB_CAIRO
+#define cairo_image_surface_get_format_LIB LIB_CAIRO
+#define cairo_image_surface_get_stride_LIB LIB_CAIRO
+#define cairo_xlib_surface_get_drawable_LIB LIB_CAIRO
+#define cairo_xlib_surface_get_height_LIB LIB_CAIRO
+#define cairo_xlib_surface_get_width_LIB LIB_CAIRO
+#define cairo_surface_get_content_LIB LIB_CAIRO
+#define cairo_push_group_LIB LIB_CAIRO
+#define cairo_pop_group_to_source_LIB LIB_CAIRO
