@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -14,8 +14,8 @@
 
 #ifdef NATIVE_STATS
 
-int OS_nativeFunctionCount = 630;
-int OS_nativeFunctionCallCount[630];
+int OS_nativeFunctionCount = 631;
+int OS_nativeFunctionCallCount[631];
 char * OS_nativeFunctionNames[] = {
 	"ATSFontActivateFromFileReference",
 	"AcquireRootMenu",
@@ -332,6 +332,7 @@ char * OS_nativeFunctionNames[] = {
 	"NSAccessibilityVisibleRowsAttribute",
 	"NSAccessibilityWindowAttribute",
 	"NSAccessibilityWindowRole",
+	"NSAddImage",
 	"NSAffineTransformStruct_1sizeof",
 	"NSApplicationDidChangeScreenParametersNotification",
 	"NSAttachmentAttributeName",
@@ -949,7 +950,6 @@ char * OS_nativeFunctionNames[] = {
 #else
 	"objc_1msgSend__JJ_3JII",
 #endif
-	"objc_1msgSend__JJFD",
 	"objc_1msgSend__JJI",
 	"objc_1msgSend__JJ_3I",
 	"objc_1msgSend__JJ_3JJJ",
@@ -1138,6 +1138,7 @@ char * OS_nativeFunctionNames[] = {
 #else
 	"objc_1msgSend_1bool__JJS",
 #endif
+	"objc_1msgSend_1floatret",
 #ifndef JNI64
 	"objc_1msgSend_1fpret__II",
 #else
