@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -340,6 +340,7 @@ typedef enum {
 	NSAccessibilityVisibleRowsAttribute_FUNC,
 	NSAccessibilityWindowAttribute_FUNC,
 	NSAccessibilityWindowRole_FUNC,
+	NSAddImage_FUNC,
 	NSAffineTransformStruct_1sizeof_FUNC,
 	NSApplicationDidChangeScreenParametersNotification_FUNC,
 	NSAttachmentAttributeName_FUNC,
@@ -957,7 +958,6 @@ typedef enum {
 #else
 	objc_1msgSend__JJ_3JII_FUNC,
 #endif
-	objc_1msgSend__JJFD_FUNC,
 	objc_1msgSend__JJI_FUNC,
 	objc_1msgSend__JJ_3I_FUNC,
 	objc_1msgSend__JJ_3JJJ_FUNC,
@@ -1146,6 +1146,7 @@ typedef enum {
 #else
 	objc_1msgSend_1bool__JJS_FUNC,
 #endif
+	objc_1msgSend_1floatret_FUNC,
 #ifndef JNI64
 	objc_1msgSend_1fpret__II_FUNC,
 #else
