@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2009 IBM Corporation and others.
+ * Copyright (c) 2000, 2011 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -25,7 +25,7 @@ public NSSlider(id id) {
 }
 
 public float /*double*/ knobThickness() {
-	return (float)OS.objc_msgSend_fpret(this.id, OS.sel_knobThickness);
+	return (float /*double*/)OS.objc_msgSend_fpret(this.id, OS.sel_knobThickness);
 }
 
 public double maxValue() {
