@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,6 +10,10 @@
  *******************************************************************************/
 package org.eclipse.swt.internal;
 
+import java.io.*;
+import java.net.*;
+import java.util.jar.*;
+
 public class Library {
 
 	/* SWT Version - Mmmm (M=major, mmm=minor) */
@@ -22,7 +26,7 @@ public class Library {
 	/**
 	 * SWT Minor version number (must be in the range 0..999)
 	 */
-    static int MINOR_VERSION = 740;
+    static int MINOR_VERSION = 834;
 	
 	/**
 	 * SWT revision number (must be >= 0)
@@ -83,6 +87,38 @@ public static int SWT_VERSION (int major, int minor) {
 	return major * 1000 + minor;
 }
 
+static boolean isLoadable () {
+	URL url = Platform.class.getClassLoader ().getResource ("org/eclipse/swt/internal/Library.class"); //$NON-NLS-1$
+	if (!url.getProtocol ().equals ("jar")) { //$NON-NLS-1$
+		/* SWT is presumably running in a development environment */
+		return true;
+	}
+
+	try {
+		url = new URL (url.getPath ());
+	} catch (MalformedURLException e) {
+		/* should never happen since url's initial path value must be valid */
+	}
+	String path = url.getPath ();
+	int index = path.indexOf ('!');
+	File file = new File (path.substring (0, index));
+
+	Attributes attributes = null;
+	try {
+		JarFile jar = new JarFile (file);
+		attributes = jar.getManifest ().getMainAttributes ();
+	} catch (IOException e) {
+		/* should never happen for a valid SWT jar with the expected manifest values */
+		return false;
+	}
+
+	String os = System.getProperty ("os.name"); //$NON-NLS-1$;
+	String arch = System.getProperty ("os.arch"); //$NON-NLS-1$
+	String manifestOS = attributes.getValue ("SWT-OS"); //$NON-NLS-1$
+	String manifestArch = attributes.getValue ("SWT-Arch"); //$NON-NLS-1$
+	return arch.equals (manifestArch) && os.equals (manifestOS);
+}
+
 /**
  * Loads the shared library that matches the version of the
  * Java code which is currently running.  SWT shared libraries
