@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others. All rights reserved.
+ * Copyright (c) 2000, 2012 IBM Corporation and others. All rights reserved.
  * The contents of this file are made available under the terms
  * of the GNU Lesser General Public License (LGPL) Version 2.1 that
  * accompanies this distribution (lgpl-v21.txt).  The LGPL is also
@@ -18,8 +18,8 @@
 
 #ifdef NATIVE_STATS
 
-int OS_nativeFunctionCount = 1396;
-int OS_nativeFunctionCallCount[1396];
+int OS_nativeFunctionCount = 1402;
+int OS_nativeFunctionCallCount[1402];
 char * OS_nativeFunctionNames[] = {
 #ifndef JNI64
 	"Call__IIII",
@@ -49,6 +49,7 @@ char * OS_nativeFunctionNames[] = {
 	"GTK_1SCROLLED_1WINDOW_1SCROLLBAR_1SPACING",
 	"GTK_1SCROLLED_1WINDOW_1VSCROLLBAR",
 	"GTK_1TEXTVIEW_1IM_1CONTEXT",
+	"GTK_1TOOLTIPS_1GET_1TIP_1TEXT",
 	"GTK_1TOOLTIPS_1SET_1ACTIVE",
 	"GTK_1TOOLTIPS_1TIP_1WINDOW",
 	"GTK_1WIDGET_1HEIGHT",
@@ -102,8 +103,6 @@ char * OS_nativeFunctionNames[] = {
 	"GtkCellRendererToggleClass_1sizeof",
 	"GtkCellRendererToggle_1sizeof",
 	"GtkColorSelectionDialog_1sizeof",
-	"GtkCombo_1sizeof",
-	"GtkFileSelection_1sizeof",
 	"GtkFixedClass_1sizeof",
 	"GtkFixed_1sizeof",
 	"GtkRequisition_1sizeof",
@@ -136,9 +135,7 @@ char * OS_nativeFunctionNames[] = {
 	"X_1EVENT_1WINDOW",
 	"_1Call",
 	"_1FcConfigAppFontAddFile",
-	"_1GDK_1DISPLAY",
 	"_1GDK_1PIXMAP_1XID",
-	"_1GDK_1ROOT_1PARENT",
 	"_1GDK_1TYPE_1COLOR",
 	"_1GDK_1TYPE_1PIXBUF",
 	"_1GString_1len",
@@ -167,7 +164,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1GTK_1WIDGET_1FLAGS",
 	"_1GTK_1WIDGET_1HAS_1DEFAULT",
 	"_1GTK_1WIDGET_1HAS_1FOCUS",
-	"_1GTK_1WIDGET_1IS_1SENSITIVE",
 	"_1GTK_1WIDGET_1MAPPED",
 	"_1GTK_1WIDGET_1SENSITIVE",
 	"_1GTK_1WIDGET_1SET_1FLAGS",
@@ -178,6 +174,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1G_1OBJECT_1GET_1CLASS",
 	"_1G_1OBJECT_1TYPE",
 	"_1G_1OBJECT_1TYPE_1NAME",
+	"_1G_1TYPE_1CHECK_1INSTANCE_1TYPE",
 	"_1G_1TYPE_1STRING",
 	"_1PANGO_1PIXELS",
 	"_1PANGO_1TYPE_1FONT_1DESCRIPTION",
@@ -250,11 +247,13 @@ char * OS_nativeFunctionNames[] = {
 	"_1g_1file_1icon_1get_1file",
 	"_1g_1file_1info_1get_1content_1type",
 	"_1g_1file_1info_1get_1modification_1time",
+	"_1g_1file_1new_1for_1commandline_1arg",
 	"_1g_1file_1new_1for_1path",
 	"_1g_1file_1new_1for_1uri",
 	"_1g_1file_1query_1info",
 	"_1g_1file_1read",
 	"_1g_1file_1test",
+	"_1g_1filename_1display_1name",
 	"_1g_1filename_1from_1uri",
 	"_1g_1filename_1from_1utf8",
 	"_1g_1filename_1to_1uri",
@@ -293,6 +292,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1g_1main_1context_1query",
 	"_1g_1main_1context_1release",
 	"_1g_1malloc",
+	"_1g_1object_1class_1find_1property",
 #ifndef JNI64
 	"_1g_1object_1get__I_3B_3II",
 #else
@@ -389,6 +389,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1g_1strtod",
 	"_1g_1thread_1init",
 	"_1g_1thread_1supported",
+	"_1g_1timeout_1add",
 	"_1g_1type_1add_1interface_1static",
 	"_1g_1type_1class_1peek",
 	"_1g_1type_1class_1peek_1parent",
@@ -429,15 +430,18 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1cairo_1region",
 	"_1gdk_1cairo_1reset_1clip",
 	"_1gdk_1cairo_1set_1source_1color",
+	"_1gdk_1cairo_1set_1source_1window",
+	"_1gdk_1color_1free",
+	"_1gdk_1color_1parse",
 	"_1gdk_1color_1white",
 	"_1gdk_1colormap_1alloc_1color",
 	"_1gdk_1colormap_1free_1colors",
 	"_1gdk_1colormap_1get_1system",
 	"_1gdk_1colormap_1query_1color",
-	"_1gdk_1cursor_1destroy",
 	"_1gdk_1cursor_1new",
 	"_1gdk_1cursor_1new_1from_1pixbuf",
 	"_1gdk_1cursor_1new_1from_1pixmap",
+	"_1gdk_1cursor_1unref",
 	"_1gdk_1display_1get_1default",
 	"_1gdk_1display_1supports_1cursor_1color",
 	"_1gdk_1drag_1status",
@@ -462,7 +466,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1event_1free",
 	"_1gdk_1event_1get",
 	"_1gdk_1event_1get_1coords",
-	"_1gdk_1event_1get_1graphics_1expose",
 	"_1gdk_1event_1get_1root_1coords",
 	"_1gdk_1event_1get_1state",
 	"_1gdk_1event_1get_1time",
@@ -471,13 +474,11 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1event_1peek",
 	"_1gdk_1event_1put",
 	"_1gdk_1flush",
-	"_1gdk_1free_1text_1list",
 	"_1gdk_1gc_1get_1values",
 	"_1gdk_1gc_1new",
 	"_1gdk_1gc_1set_1background",
 	"_1gdk_1gc_1set_1clip_1mask",
 	"_1gdk_1gc_1set_1clip_1origin",
-	"_1gdk_1gc_1set_1clip_1rectangle",
 	"_1gdk_1gc_1set_1clip_1region",
 	"_1gdk_1gc_1set_1dashes",
 	"_1gdk_1gc_1set_1exposures",
@@ -490,6 +491,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1gc_1set_1tile",
 	"_1gdk_1gc_1set_1ts_1origin",
 	"_1gdk_1gc_1set_1values",
+	"_1gdk_1get_1default_1root_1window",
 	"_1gdk_1keyboard_1ungrab",
 	"_1gdk_1keymap_1get_1default",
 	"_1gdk_1keymap_1translate_1keyboard_1state",
@@ -514,7 +516,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1pixbuf_1new_1from_1file",
 	"_1gdk_1pixbuf_1render_1pixmap_1and_1mask",
 	"_1gdk_1pixbuf_1render_1to_1drawable",
-	"_1gdk_1pixbuf_1render_1to_1drawable_1alpha",
 	"_1gdk_1pixbuf_1save_1to_1bufferv",
 	"_1gdk_1pixbuf_1scale",
 	"_1gdk_1pixbuf_1scale_1simple",
@@ -538,7 +539,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1region_1subtract",
 	"_1gdk_1region_1union",
 	"_1gdk_1region_1union_1with_1rect",
-	"_1gdk_1rgb_1init",
 	"_1gdk_1screen_1get_1default",
 	"_1gdk_1screen_1get_1monitor_1at_1point",
 	"_1gdk_1screen_1get_1monitor_1at_1window",
@@ -549,7 +549,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1screen_1width",
 	"_1gdk_1screen_1width_1mm",
 	"_1gdk_1set_1program_1class",
-	"_1gdk_1text_1property_1to_1utf8_1list",
+	"_1gdk_1text_1property_1to_1utf8_1list_1for_1display",
 	"_1gdk_1unicode_1to_1keyval",
 	"_1gdk_1utf8_1to_1compound_1text",
 	"_1gdk_1utf8_1to_1string_1target",
@@ -558,6 +558,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1window_1at_1pointer",
 	"_1gdk_1window_1begin_1paint_1rect",
 	"_1gdk_1window_1clear_1area",
+	"_1gdk_1window_1create_1similar_1surface",
 	"_1gdk_1window_1destroy",
 	"_1gdk_1window_1end_1paint",
 	"_1gdk_1window_1focus",
@@ -605,11 +606,13 @@ char * OS_nativeFunctionNames[] = {
 	"_1gdk_1window_1thaw_1updates",
 	"_1gdk_1x11_1atom_1to_1xatom",
 	"_1gdk_1x11_1colormap_1get_1xcolormap",
+	"_1gdk_1x11_1display_1get_1xdisplay",
 	"_1gdk_1x11_1drawable_1get_1xdisplay",
 	"_1gdk_1x11_1drawable_1get_1xid",
 	"_1gdk_1x11_1screen_1get_1window_1manager_1name",
 	"_1gdk_1x11_1screen_1lookup_1visual",
 	"_1gdk_1x11_1visual_1get_1xvisual",
+	"_1gdk_1x11_1window_1lookup_1for_1display",
 	"_1gtk_1accel_1group_1new",
 	"_1gtk_1accel_1groups_1activate",
 	"_1gtk_1accel_1label_1set_1accel_1widget",
@@ -630,7 +633,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1button_1new",
 	"_1gtk_1button_1set_1relief",
 	"_1gtk_1calendar_1clear_1marks",
-	"_1gtk_1calendar_1display_1options",
 	"_1gtk_1calendar_1get_1date",
 	"_1gtk_1calendar_1mark_1day",
 	"_1gtk_1calendar_1new",
@@ -638,6 +640,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1calendar_1select_1month",
 	"_1gtk_1calendar_1set_1display_1options",
 	"_1gtk_1cell_1layout_1clear",
+	"_1gtk_1cell_1layout_1get_1cells",
 	"_1gtk_1cell_1layout_1pack_1start",
 	"_1gtk_1cell_1layout_1set_1attributes",
 	"_1gtk_1cell_1renderer_1get_1size",
@@ -658,6 +661,8 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1clipboard_1wait_1for_1contents",
 	"_1gtk_1color_1selection_1dialog_1new",
 	"_1gtk_1color_1selection_1get_1current_1color",
+	"_1gtk_1color_1selection_1palette_1from_1string",
+	"_1gtk_1color_1selection_1palette_1to_1string",
 	"_1gtk_1color_1selection_1set_1current_1color",
 	"_1gtk_1color_1selection_1set_1has_1palette",
 	"_1gtk_1combo_1box_1entry_1new_1text",
@@ -670,10 +675,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1combo_1box_1remove_1text",
 	"_1gtk_1combo_1box_1set_1active",
 	"_1gtk_1combo_1box_1set_1focus_1on_1click",
-	"_1gtk_1combo_1disable_1activate",
-	"_1gtk_1combo_1new",
-	"_1gtk_1combo_1set_1case_1sensitive",
-	"_1gtk_1combo_1set_1popdown_1strings",
 	"_1gtk_1container_1add",
 	"_1gtk_1container_1forall",
 	"_1gtk_1container_1get_1border_1width",
@@ -753,12 +754,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1file_1filter_1get_1name",
 	"_1gtk_1file_1filter_1new",
 	"_1gtk_1file_1filter_1set_1name",
-	"_1gtk_1file_1selection_1get_1filename",
-	"_1gtk_1file_1selection_1get_1selections",
-	"_1gtk_1file_1selection_1hide_1fileop_1buttons",
-	"_1gtk_1file_1selection_1new",
-	"_1gtk_1file_1selection_1set_1filename",
-	"_1gtk_1file_1selection_1set_1select_1multiple",
 	"_1gtk_1fixed_1move",
 	"_1gtk_1fixed_1new",
 	"_1gtk_1fixed_1set_1has_1window",
@@ -828,12 +823,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1label_1set_1text__J_3B",
 #endif
 	"_1gtk_1label_1set_1text_1with_1mnemonic",
-	"_1gtk_1list_1append_1items",
-	"_1gtk_1list_1clear_1items",
-	"_1gtk_1list_1insert_1items",
-	"_1gtk_1list_1item_1new_1with_1label",
-	"_1gtk_1list_1remove_1items",
-	"_1gtk_1list_1select_1item",
 	"_1gtk_1list_1store_1append",
 	"_1gtk_1list_1store_1clear",
 	"_1gtk_1list_1store_1insert",
@@ -864,8 +853,6 @@ char * OS_nativeFunctionNames[] = {
 #else
 	"_1gtk_1list_1store_1set__JJI_3BJ",
 #endif
-	"_1gtk_1list_1unselect_1all",
-	"_1gtk_1list_1unselect_1item",
 	"_1gtk_1main",
 	"_1gtk_1main_1do_1event",
 	"_1gtk_1main_1iteration",
@@ -882,6 +869,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1menu_1shell_1insert",
 	"_1gtk_1menu_1shell_1select_1item",
 	"_1gtk_1menu_1shell_1set_1take_1focus",
+	"_1gtk_1menu_1tool_1button_1new",
 	"_1gtk_1message_1dialog_1new",
 	"_1gtk_1micro_1version",
 	"_1gtk_1minor_1version",
@@ -898,6 +886,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1notebook_1set_1show_1tabs",
 	"_1gtk_1notebook_1set_1tab_1pos",
 	"_1gtk_1object_1sink",
+	"_1gtk_1orientable_1set_1orientation",
 	"_1gtk_1page_1setup_1get_1bottom_1margin",
 	"_1gtk_1page_1setup_1get_1left_1margin",
 	"_1gtk_1page_1setup_1get_1orientation",
@@ -1022,8 +1011,11 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1selection_1data_1free",
 	"_1gtk_1selection_1data_1set",
 	"_1gtk_1separator_1menu_1item_1new",
+	"_1gtk_1separator_1tool_1item_1new",
+	"_1gtk_1separator_1tool_1item_1set_1draw",
 	"_1gtk_1set_1locale",
 	"_1gtk_1settings_1get_1default",
+	"_1gtk_1settings_1set_1string_1property",
 	"_1gtk_1socket_1get_1id",
 	"_1gtk_1socket_1new",
 	"_1gtk_1spin_1button_1configure",
@@ -1111,18 +1103,30 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1text_1view_1set_1tabs",
 	"_1gtk_1text_1view_1set_1wrap_1mode",
 	"_1gtk_1text_1view_1window_1to_1buffer_1coords",
-	"_1gtk_1timeout_1add",
-	"_1gtk_1timeout_1remove",
 	"_1gtk_1toggle_1button_1get_1active",
 	"_1gtk_1toggle_1button_1get_1inconsistent",
 	"_1gtk_1toggle_1button_1new",
 	"_1gtk_1toggle_1button_1set_1active",
 	"_1gtk_1toggle_1button_1set_1inconsistent",
 	"_1gtk_1toggle_1button_1set_1mode",
+	"_1gtk_1toggle_1tool_1button_1get_1active",
+	"_1gtk_1toggle_1tool_1button_1new",
+	"_1gtk_1toggle_1tool_1button_1set_1active",
+	"_1gtk_1tool_1button_1new",
+	"_1gtk_1tool_1button_1set_1icon_1widget",
+	"_1gtk_1tool_1button_1set_1label",
+	"_1gtk_1tool_1button_1set_1label_1widget",
+	"_1gtk_1tool_1button_1set_1use_1underline",
+	"_1gtk_1tool_1item_1get_1proxy_1menu_1item",
+	"_1gtk_1tool_1item_1retrieve_1proxy_1menu_1item",
+	"_1gtk_1tool_1item_1set_1is_1important",
+	"_1gtk_1tool_1item_1set_1proxy_1menu_1item",
+	"_1gtk_1toolbar_1insert",
 	"_1gtk_1toolbar_1insert_1widget",
 	"_1gtk_1toolbar_1new",
 	"_1gtk_1toolbar_1set_1orientation",
-	"_1gtk_1tooltip_1trigger_1tooltip_1query",
+	"_1gtk_1toolbar_1set_1show_1arrow",
+	"_1gtk_1toolbar_1set_1style",
 	"_1gtk_1tooltips_1data_1get",
 	"_1gtk_1tooltips_1disable",
 	"_1gtk_1tooltips_1enable",
@@ -1237,6 +1241,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1tree_1view_1column_1set_1title",
 	"_1gtk_1tree_1view_1column_1set_1visible",
 	"_1gtk_1tree_1view_1column_1set_1widget",
+	"_1gtk_1tree_1view_1convert_1widget_1to_1bin_1window_1coords",
 	"_1gtk_1tree_1view_1create_1row_1drag_1icon",
 	"_1gtk_1tree_1view_1expand_1row",
 	"_1gtk_1tree_1view_1get_1background_1area",
@@ -1266,7 +1271,6 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1tree_1view_1set_1model",
 	"_1gtk_1tree_1view_1set_1rules_1hint",
 	"_1gtk_1tree_1view_1set_1search_1column",
-	"_1gtk_1tree_1view_1tree_1to_1widget_1coords",
 	"_1gtk_1tree_1view_1unset_1rows_1drag_1dest",
 	"_1gtk_1tree_1view_1widget_1to_1tree_1coords",
 	"_1gtk_1vbox_1new",
@@ -1302,6 +1306,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1gtk_1widget_1get_1parent_1window",
 	"_1gtk_1widget_1get_1size_1request",
 	"_1gtk_1widget_1get_1style",
+	"_1gtk_1widget_1get_1tooltip_1text",
 	"_1gtk_1widget_1get_1toplevel",
 	"_1gtk_1widget_1grab_1focus",
 	"_1gtk_1widget_1hide",
@@ -1407,6 +1412,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1pango_1attr_1underline_1color_1new",
 	"_1pango_1attr_1underline_1new",
 	"_1pango_1attr_1weight_1new",
+	"_1pango_1attribute_1copy",
 	"_1pango_1cairo_1context_1get_1font_1options",
 	"_1pango_1cairo_1context_1set_1font_1options",
 	"_1pango_1cairo_1create_1layout",
@@ -1495,6 +1501,7 @@ char * OS_nativeFunctionNames[] = {
 	"_1pango_1tab_1array_1get_1tabs",
 	"_1pango_1tab_1array_1new",
 	"_1pango_1tab_1array_1set_1tab",
+	"_1ubuntu_1menu_1proxy_1get",
 	"g_1main_1context_1wakeup",
 	"g_1value_1get_1double",
 	"g_1value_1get_1float",
@@ -1526,6 +1533,11 @@ char * OS_nativeFunctionNames[] = {
 #else
 	"memmove__JLorg_eclipse_swt_internal_gtk_GTypeInfo_2I",
 #endif
+#ifndef JNI64
+	"memmove__ILorg_eclipse_swt_internal_gtk_GdkColor_2I",
+#else
+	"memmove__JLorg_eclipse_swt_internal_gtk_GdkColor_2J",
+#endif
 #ifndef JNI64
 	"memmove__ILorg_eclipse_swt_internal_gtk_GdkEventButton_2I",
 #else
@@ -1706,16 +1718,6 @@ char * OS_nativeFunctionNames[] = {
 #else
 	"memmove__Lorg_eclipse_swt_internal_gtk_GtkColorSelectionDialog_2J",
 #endif
-#ifndef JNI64
-	"memmove__Lorg_eclipse_swt_internal_gtk_GtkCombo_2I",
-#else
-	"memmove__Lorg_eclipse_swt_internal_gtk_GtkCombo_2J",
-#endif
-#ifndef JNI64
-	"memmove__Lorg_eclipse_swt_internal_gtk_GtkFileSelection_2I",
-#else
-	"memmove__Lorg_eclipse_swt_internal_gtk_GtkFileSelection_2J",
-#endif
 #ifndef JNI64
 	"memmove__Lorg_eclipse_swt_internal_gtk_GtkFixed_2I",
 #else
@@ -1793,6 +1795,7 @@ char * OS_nativeFunctionNames[] = {
 #endif
 	"pangoLayoutNewProc_1CALLBACK",
 	"realpath",
+	"strcmp",
 };
 
 #define STATS_NATIVE(func) Java_org_eclipse_swt_tools_internal_NativeStats_##func
