@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -139,17 +139,21 @@ public void drawBackground (GC gc, int x, int y, int width, int height) {
 void drawBackground (int /*long*/ id, NSGraphicsContext context, NSRect rect) {
 	super.drawBackground(id, context, rect);
 	if (glcontext != null) {
-		context.saveGraphicsState();
-		context.setCompositingOperation(OS.NSCompositeClear);
-		if (visiblePath == null) {
-			int /*long*/ visibleRegion = getVisibleRegion();
-			visiblePath = getPath(visibleRegion);
-			OS.DisposeRgn(visibleRegion);
+		if (isObscured()) {
+			glcontext.setValues(new int[]{-1}, OS.NSOpenGLCPSurfaceOrder);
+			context.saveGraphicsState();
+			context.setCompositingOperation(OS.NSCompositeClear);
+			if (visiblePath == null) {
+				int /*long*/ visibleRegion = getVisibleRegion();
+				visiblePath = getPath(visibleRegion);
+				OS.DisposeRgn(visibleRegion);
+			}
+			visiblePath.addClip();
+			NSBezierPath.fillRect(rect);
+			context.restoreGraphicsState();
+		} else {
+			glcontext.setValues(new int[]{1}, OS.NSOpenGLCPSurfaceOrder);
 		}
-		visiblePath.addClip();
-		NSBezierPath.fillRect(rect);
-		context.restoreGraphicsState();
-		return;
 	}
 }
 
@@ -535,12 +539,13 @@ public void setFont (Font font) {
 
 void setOpenGLContext(Object value) {
 	glcontext = (NSOpenGLContext)value;
-	NSWindow window = view.window();
+	Shell shell = getShell ();
 	if (glcontext != null) {
-		window.setOpaque(false);
+		shell.glContextCount++;
 	} else {
-		window.setOpaque(getShell().region == null);
+		shell.glContextCount--;
 	}
+	shell.updateOpaque ();
 }
 
 /**
@@ -608,13 +613,15 @@ void updateOpenGLContext(int /*long*/ id, int /*long*/ sel, int /*long*/ notific
 
 void viewWillMoveToWindow(int /*long*/ id, int /*long*/ sel, int /*long*/ arg0) {	
 	super.viewWillMoveToWindow(id, sel, arg0);
-	if (glcontext != null) {
-		new NSWindow(arg0).setOpaque(false);
-		Shell shell = getShell();
-		NSWindow window = shell.window;
-		if (window != null) {
-			window.setOpaque(shell.region == null);
+	if (glcontext != null && id == view.id && arg0 != 0) {
+		Widget newShell = display.getWidget(new NSWindow(arg0).contentView());
+		if (newShell instanceof Shell) {
+			((Shell) newShell).glContextCount++;
+			((Shell) newShell).updateOpaque();
 		}
+		Shell shell = getShell();
+		shell.glContextCount--;
+		shell.updateOpaque();
 	}
 }
 
