@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -123,6 +123,7 @@ public class Shell extends Decorations {
 	int /*long*/ hostWindowClass;
 	NSWindow hostWindow;
 	int /*long*/ tooltipOwner, tooltipTag, tooltipUserData;
+	int glContextCount;
 	boolean opened, moved, resized, fullScreen, center, deferFlushing, scrolling, isPopup;
 	Control lastActive;
 	Rectangle normalBounds;
@@ -417,17 +418,6 @@ public static Shell cocoa_new (Display display, int /*long*/ handle) {
 	return new Shell (display, null, SWT.NO_TRIM, handle, true);
 }
 
-Control [] _getChildren () {
-	Control [] children = super._getChildren();
-	if (toolBar != null) {
-		Control [] newChildren = new Control [children.length + 1];
-		System.arraycopy (children, 0, newChildren, 1, children.length);
-		newChildren[0] = toolBar;
-		children = newChildren;
-	}
-	return children;
-}
-
 static int checkStyle (Shell parent, int style) {
 	style = Decorations.checkStyle (style);
 	style &= ~SWT.TRANSPARENT;
@@ -548,6 +538,16 @@ boolean canBecomeKeyWindow (int /*long*/ id, int /*long*/ sel) {
 	if (isPopup) return false;
 	// Only answer if SWT created the window.
 	if (window != null) {
+		if ((style & SWT.NO_FOCUS) != 0) {
+			NSEvent nsEvent = NSApplication.sharedApplication().currentEvent();
+			if (nsEvent != null && nsEvent.type() == OS.NSLeftMouseDown) {
+				NSView contentView = window.contentView();
+				if (contentView != null) {
+					NSView view = contentView.hitTest(nsEvent.locationInWindow());
+					if (view == contentView) return false;
+				}
+			}
+		}
 		int /*long*/ styleMask = window.styleMask();
 		if (styleMask == OS.NSBorderlessWindowMask || (styleMask & (OS.NSNonactivatingPanelMask | OS.NSDocModalWindowMask | OS.NSResizableWindowMask)) != 0) return true;
 	}
@@ -611,6 +611,17 @@ void closeWidget (boolean force) {
 	if ((force || event.doit) && !isDisposed ()) dispose ();
 }
 
+public Point computeSize (int wHint, int hHint, boolean changed) {
+	Point size = super.computeSize (wHint, hHint, changed);
+	if (toolBar != null) {
+		if (wHint == SWT.DEFAULT && toolBar.itemCount > 0) {
+			Point tbSize = toolBar.computeSize (SWT.DEFAULT, SWT.DEFAULT);
+			size.x = Math.max (tbSize.x, size.x);
+		}
+	}
+	return size;
+}
+
 public Rectangle computeTrim (int x, int y, int width, int height) {
 	checkWidget();
 	Rectangle trim = super.computeTrim(x, y, width, height);
@@ -726,7 +737,14 @@ void createHandle () {
 		NSWindow hostWindow = view.window();
 		attachObserversToWindow(hostWindow);
 	} else {
-		if (parent != null) window.setCollectionBehavior(OS.NSWindowCollectionBehaviorMoveToActiveSpace);
+		int behavior = 0;
+		if (parent != null) behavior |= OS.NSWindowCollectionBehaviorMoveToActiveSpace;
+		if (OS.VERSION >= 0x1070) {
+			if (parent == null) {
+				behavior = OS.NSWindowCollectionBehaviorFullScreenPrimary;
+			}
+		}
+		if (behavior != 0) window.setCollectionBehavior(behavior);
 		window.setAcceptsMouseMovedEvents(true);
 		window.setDelegate(windowDelegate);
 	}
@@ -742,6 +760,7 @@ void createHandle () {
 	id id = fieldEditorWindow.fieldEditor (true, null);
 	if (id != null) {
 		OS.object_setClass (id.id, OS.objc_getClass ("SWTEditorView"));
+		new NSTextView(id).setAllowsUndo(true);
 	}
 
 }
@@ -1178,7 +1197,9 @@ float getThemeAlpha () {
  */
 public ToolBar getToolBar() {
 	checkWidget();
-	if (toolBar == null) toolBar = new ToolBar(this, SWT.HORIZONTAL | SWT.SMOOTH, true);
+	if ((style & SWT.NO_TRIM) == 0) {
+		if (toolBar == null) toolBar = new ToolBar(this, SWT.HORIZONTAL | SWT.SMOOTH, true);
+	}
 	return toolBar;
 }
 
@@ -1203,6 +1224,7 @@ void helpRequested(int /*long*/ id, int /*long*/ sel, int /*long*/ theEvent) {
 
 void invalidateVisibleRegion () {
 	resetVisibleRegion ();
+	if (toolBar != null) toolBar.resetVisibleRegion();
 	invalidateChildrenVisibleRegion ();
 }
 
@@ -1219,6 +1241,10 @@ boolean isEnabledCursor () {
 	return true;
 }
 
+boolean isResizing () {
+	return (state & RESIZING) != 0;
+}
+
 boolean isTransparent() {
 	return false;
 }
@@ -1252,26 +1278,6 @@ void makeKeyAndOrderFront() {
 	window.makeKeyAndOrderFront (null);
 }
 
-Point minimumSize (int wHint, int Hint, boolean changed) {
-	// minimumSize is used by computeSize() to figure out how big the view
-	// (or, in this case, the content view of the Shell) should be.
-	// An NSToolbar does not contribute to the content area, but must be
-	// accounted for. If the shell has a toolbar but no other children
-	// this will return the width of the toolbar and a height of 1
-	Control [] children = _getChildren ();
-	int width = 0, height = 0;
-	for (int i=0; i<children.length; i++) {
-		Rectangle rect = children [i].getBounds ();
-		width = Math.max (width, rect.x + rect.width);
-		if (children[i] != toolBar)	{
-			height = Math.max (height, rect.y + rect.height);
-		} else {
-			height = Math.max (height, 1);
-		}
-	}
-	return new Point (width, height);
-}
-
 void mouseMoved(int /*long*/ id, int /*long*/ sel, int /*long*/ theEvent) {
 	super.mouseMoved(id, sel, theEvent);
 
@@ -1388,6 +1394,10 @@ void releaseParent () {
 
 void releaseWidget () {
 	super.releaseWidget ();
+	if (toolBar != null) {
+		toolBar.dispose();
+		toolBar = null;
+	}
 	if (tooltipTag != 0) {
 		view.window().contentView().removeToolTip(tooltipTag);
 		tooltipTag = 0;
@@ -1450,6 +1460,7 @@ public void removeShellListener(ShellListener listener) {
 }
 
 void reskinChildren (int flags) {
+	if (toolBar != null) toolBar.reskin(flags);
 	Shell [] shells = getShells ();
 	for (int i=0; i<shells.length; i++) {
 		Shell shell = shells [i];
@@ -1672,8 +1683,14 @@ public void setEnabled (boolean enabled) {
  */
 public void setFullScreen (boolean fullScreen) {
 	checkWidget ();
+	if (window == null) return;
 	if (this.fullScreen == fullScreen) return;
-	this.fullScreen = fullScreen; 
+	this.fullScreen = fullScreen;
+	
+	if ((window.collectionBehavior() & OS.NSWindowCollectionBehaviorFullScreenPrimary) != 0) {
+		OS.objc_msgSend(window.id, OS.sel_toggleFullScreen_, 0);
+		return;
+	}
 
 	if (fullScreen) {
 		currentFrame = window.frame();
@@ -1857,11 +1874,10 @@ public void setRegion (Region region) {
 	regionPath = getPath(region);
 	if (region != null) {
 		window.setBackgroundColor(NSColor.clearColor());
-		window.setOpaque(false);
 	} else {
 		window.setBackgroundColor(NSColor.windowBackgroundColor());
-		window.setOpaque(true);
 	}
+	updateOpaque ();
 	window.contentView().setNeedsDisplay(true);
 	if (isVisible() && window.hasShadow()) {
 		window.display();
@@ -1933,7 +1949,7 @@ void setWindowVisible (boolean visible, boolean key) {
 				// when its parent is shown.
 				boolean parentMinimized = parent != null && parentWindow ().isMiniaturized();
 				if (!parentMinimized) {
-					if (key) {
+					if (key && (style & SWT.NO_FOCUS) == 0) {
 						makeKeyAndOrderFront ();
 					} else {
 						window.orderFront (null);
@@ -2020,10 +2036,20 @@ boolean traverseEscape () {
 	return true;
 }
 
+void updateCursorRects(boolean enabled) {
+	super.updateCursorRects(enabled);
+	if (toolBar != null) toolBar.updateCursorRects(enabled);
+};
+
 void updateModal () {
 	// do nothing
 }
 
+void updateOpaque () {
+	if (window == null) return;
+	window.setOpaque (region == null && glContextCount == 0);
+}
+
 void updateParent (boolean visible) {
 	if (window != null) {
 		if (visible) {
@@ -2054,6 +2080,7 @@ void updateParent (boolean visible) {
 }
 
 void updateSystemUIMode () {
+	if ((window.collectionBehavior() & OS.NSWindowCollectionBehaviorFullScreenPrimary) != 0) return;
 	if (!getMonitor ().equals (display.getPrimaryMonitor ())) return;
 	int mode = display.systemUIMode, options = display.systemUIOptions;
 	if (fullScreen) {
@@ -2104,17 +2131,19 @@ void windowDidBecomeKey(int /*long*/ id, int /*long*/ sel, int /*long*/ notifica
 	if (isDisposed ()) return;
 	if (!restoreFocus () && !traverseGroup (true)) setFocus ();
 	if (isDisposed ()) return;
-	Shell parentShell = this;
-	while (parentShell.parent != null) {
-		parentShell = (Shell) parentShell.parent;
-		if (parentShell.fullScreen) {
-			break;
+	if ((window.collectionBehavior() & OS.NSWindowCollectionBehaviorFullScreenPrimary) == 0) {
+		Shell parentShell = this;
+		while (parentShell.parent != null) {
+			parentShell = (Shell) parentShell.parent;
+			if (parentShell.fullScreen) {
+				break;
+			}
+		}
+		if (!parentShell.fullScreen || menuBar != null) {
+			updateSystemUIMode ();
+		} else {
+			parentShell.updateSystemUIMode ();
 		}
-	}
-	if (!parentShell.fullScreen || menuBar != null) {
-		updateSystemUIMode ();
-	} else {
-		parentShell.updateSystemUIMode ();
 	}
 }
 
@@ -2128,13 +2157,21 @@ void windowDidMiniturize(int /*long*/ id, int /*long*/ sel, int /*long*/ notific
 	sendEvent(SWT.Iconify);
 }
 
+void windowDidEnterFullScreen(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
+	this.fullScreen = true;
+}
+
+void windowDidExitFullScreen(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
+	this.fullScreen = false;
+}
+
 void windowDidMove(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
 	moved = true;
 	sendEvent(SWT.Move);
 }
 
 void windowDidResize(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
-	if (fullScreen) {
+	if (fullScreen && ((window.collectionBehavior() & OS.NSWindowCollectionBehaviorFullScreenPrimary) == 0)) {
 		window.setFrame(fullScreenFrame, true);
 		NSRect contentViewFrame = new NSRect();
 		contentViewFrame.width = fullScreenFrame.width;
@@ -2223,6 +2260,15 @@ void windowSendEvent (int /*long*/ id, int /*long*/ sel, int /*long*/ event) {
 			break;
 			
 		case OS.NSKeyDown:
+			/*
+			* Feature in Cocoa.  For some reason, Cocoa does not perform accelerators
+			* with ESC key code.  The fix is to perform the accelerators ourselves. 
+			*/
+			if (nsEvent.keyCode() == 53 /* ESC */ && menuBar != null && !menuBar.isDisposed()) {
+				if (menuBar.nsMenu.performKeyEquivalent(nsEvent)) {
+					return;
+				}
+			}
 			/**
 			 * Feature in cocoa.  Control+Tab, Ctrl+Shift+Tab, Ctrl+PageDown and Ctrl+PageUp are
 			 * swallowed to handle native traversal. If we find that, force the key event to
