@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -355,6 +355,11 @@ void drawInteriorWithFrame_inView(int id, int sel, NSRect cellFrame, int viewid)
 	super.drawInteriorWithFrame_inView(id, sel, cellFrame, viewid);
 }
 
+Cursor findCursor () {
+	Cursor cursor = super.findCursor ();
+	return (cursor != null || (style & SWT.READ_ONLY) != 0) ? cursor : display.getSystemCursor (SWT.CURSOR_IBEAM);
+}
+
 NSView focusView () {
 	return textView;
 }
