@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2010 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -208,7 +208,11 @@ public Point computeSize (int wHint, int hHint, boolean changed) {
 
 public Rectangle computeTrim (int x, int y, int width, int height) {
 	checkWidget();
-	if (scrollView != null) {
+	if (nsToolbar != null) {
+		NSRect outer = view.frame();
+		NSRect inner = new NSView(view.subviews().objectAtIndex(0)).frame();
+		width += (int)outer.width - (int)inner.width;
+	} else if (scrollView != null) {
 		NSSize size = new NSSize();
 		size.width = width;
 		size.height = height;
@@ -364,7 +368,7 @@ boolean forceFocus (NSView focusView) {
 			return true;
 		}
 	}
-	return super.forceFocus (focusView);
+	return false;
 }
 
 /**
@@ -405,12 +409,12 @@ public ToolItem getItem (int index) {
  *    <li>ERROR_THREAD_INVALID_ACCESS - if not called from the thread that created the receiver</li>
  * </ul>
  */
-public ToolItem getItem (Point pt) {
+public ToolItem getItem (Point point) {
 	checkWidget();
-	if (pt == null) error (SWT.ERROR_NULL_ARGUMENT);
+	if (point == null) error (SWT.ERROR_NULL_ARGUMENT);
 	for (int i=0; i<itemCount; i++) {
 		Rectangle rect = items [i].getBounds ();
-		if (rect.contains (pt)) return items [i];
+		if (rect.contains (point)) return items [i];
 	}
 	return null;
 }
