@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -78,16 +78,17 @@ public abstract class Widget {
 	static final int DISPOSE_SENT = 1<<16;	
 	static final int FOREIGN_HANDLE = 1<<17;
 	static final int DRAG_DETECT = 1<<18;
+	static final int RESIZING = 1<<19;
 
 	/* WebKit fixes */
-	static final int WEBKIT_EVENTS_FIX = 1<<19;
+	static final int WEBKIT_EVENTS_FIX = 1<<20;
 	static final String WEBKIT_EVENTS_FIX_KEY = "org.eclipse.swt.internal.webKitEventsFix"; //$NON-NLS-1$
 	static final String GLCONTEXT_KEY = "org.eclipse.swt.internal.cocoa.glcontext"; //$NON-NLS-1$
 	
 	static final String IS_ACTIVE = "org.eclipse.swt.internal.isActive"; //$NON-NLS-1$
 
 	/* Notify of the opportunity to skin this widget */
-	static final int SKIN_NEEDED = 1<<20;
+	static final int SKIN_NEEDED = 1<<21;
 	
 	/* Default size for widgets */
 	static final int DEFAULT_WIDTH	= 64;
@@ -1356,11 +1357,11 @@ void releaseWidget () {
  * @see #getListeners(int)
  * @see #notifyListeners
  */
-public void removeListener (int eventType, Listener handler) {
+public void removeListener (int eventType, Listener listener) {
 	checkWidget();
-	if (handler == null) error (SWT.ERROR_NULL_ARGUMENT);
+	if (listener == null) error (SWT.ERROR_NULL_ARGUMENT);
 	if (eventTable == null) return;
-	eventTable.unhook (eventType, handler);
+	eventTable.unhook (eventType, listener);
 }
 
 /**
@@ -2091,6 +2092,12 @@ void windowDidMiniturize(int /*long*/ id, int /*long*/ sel, int /*long*/ notific
 void windowDidDeminiturize(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
 }
 
+void windowDidEnterFullScreen(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
+}
+
+void windowDidExitFullScreen(int /*long*/ id, int /*long*/ sel, int /*long*/ notification) {
+}
+
 void windowSendEvent(int /*long*/ id, int /*long*/ sel, int /*long*/ event) {
 	callSuper(id, sel, event);
 }
