@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2011 IBM Corporation and others.
+ * Copyright (c) 2005, 2012 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -404,6 +404,7 @@ public class WorkbenchMessages extends NLS {
 	public static String NewWizardsRegistryReader_otherCategory;
 	public static String NewWizardDropDown_text;
 	
+	public static String WizardHandler_menuLabel;
 	public static String WorkbenchWizard_errorMessage;
 	public static String WorkbenchWizard_errorTitle;
 	public static String WizardTransferPage_selectAll;
@@ -1008,6 +1009,7 @@ public class WorkbenchMessages extends NLS {
     public static String ContentTypes_lockedFormat;
     public static String ContentTypes_characterSetLabel;
     public static String ContentTypes_characterSetUpdateLabel;
+    public static String ContentTypes_unsupportedEncoding;
     public static String ContentTypes_fileAssociationsLabel;
     public static String ContentTypes_fileAssociationsAddLabel;
     public static String ContentTypes_fileAssociationsEditLabel;
